class Marshal(object):
 """ Provides a collection of methods for allocating unmanaged memory,copying unmanaged memory blocks,and converting managed to unmanaged types,as well as other miscellaneous methods used when interacting with unmanaged code. """
 @staticmethod
 def AddRef(pUnk):
  """
  AddRef(pUnk: IntPtr) -> int

  

   Increments the reference count on the specified interface.

  

   pUnk: The interface reference count to increment.

   Returns: The new value of the reference count on the pUnk parameter.
  """
  pass
 @staticmethod
 def AllocCoTaskMem(cb):
  """
  AllocCoTaskMem(cb: int) -> IntPtr

  

   Allocates a block of memory of specified size from the COM task memory allocator.

  

   cb: The size of the block of memory to be allocated.

   Returns: An integer representing the address of the block of memory allocated. This memory must be 

    released with System.Runtime.InteropServices.Marshal.FreeCoTaskMem(System.IntPtr).
  """
  pass
 @staticmethod
 def AllocHGlobal(cb):
  """
  AllocHGlobal(cb: int) -> IntPtr

  

   Allocates memory from the unmanaged memory of the process by using the specified number of bytes.

  

   cb: The required number of bytes in memory.

   Returns: A pointer to the newly allocated memory. This memory must be released using the 

    System.Runtime.InteropServices.Marshal.FreeHGlobal(System.IntPtr) method.

  

  AllocHGlobal(cb: IntPtr) -> IntPtr

  

   Allocates memory from the unmanaged memory of the process by using the pointer to the specified 

    number of bytes.

  

  

   cb: The required number of bytes in memory.

   Returns: A pointer to the newly allocated memory. This memory must be released using the 

    System.Runtime.InteropServices.Marshal.FreeHGlobal(System.IntPtr) method.
  """
  pass
 @staticmethod
 def AreComObjectsAvailableForCleanup():
  """
  AreComObjectsAvailableForCleanup() -> bool

  

   Indicates whether runtime callable wrappers (RCWs) from any context are available for cleanup.

   Returns: true if there are any RCWs available for cleanup; otherwise,false.
  """
  pass
 @staticmethod
 def BindToMoniker(monikerName):
  """
  BindToMoniker(monikerName: str) -> object

  

   Gets an interface pointer identified by the specified moniker.

  

   monikerName: The moniker corresponding to the desired interface pointer.

   Returns: An object containing a reference to the interface pointer identified by the monikerName 

    parameter. A moniker is a name,and in this case,the moniker is defined by an interface.
  """
  pass
 @staticmethod
 def ChangeWrapperHandleStrength(otp,fIsWeak):
  """
  ChangeWrapperHandleStrength(otp: object,fIsWeak: bool)

   Changes the strength of an object's COM Callable Wrapper (CCW) handle.

  

   otp: The object whose CCW holds a reference counted handle. The handle is strong if the reference 

    count on the CCW is greater than zero; otherwise,it is weak.

  

   fIsWeak: true to change the strength of the handle on the otp parameter to weak,regardless of its 

    reference count; false to reset the handle strength on otp to be reference counted.
  """
  pass
 @staticmethod
 def CleanupUnusedObjectsInCurrentContext():
  """
  CleanupUnusedObjectsInCurrentContext()

   Notifies the runtime to clean up all Runtime Callable Wrappers (RCWs) allocated in the current 

    context.
  """
  pass
 @staticmethod
 def Copy(source,*__args):
  """
  Copy(source: IntPtr,destination: Array[Int16],startIndex: int,length: int)

   Copies data from an unmanaged memory pointer to a managed 16-bit signed integer array.

  

   source: The memory pointer to copy from.

   destination: The array to copy to.

   startIndex: The zero-based index in the destination  array where copying should start.

   length: The number of array elements to copy.

  Copy(source: IntPtr,destination: Array[Int64],startIndex: int,length: int)

   Copies data from an unmanaged memory pointer to a managed 64-bit signed integer array.

  

   source: The memory pointer to copy from.

   destination: The array to copy to.

   startIndex: The zero-based index in the destination  array where copying should start.

   length: The number of array elements to copy.

  Copy(source: IntPtr,destination: Array[int],startIndex: int,length: int)

   Copies data from an unmanaged memory pointer to a managed 32-bit signed integer array.

  

   source: The memory pointer to copy from.

   destination: The array to copy to.

   startIndex: The zero-based index in the destination  array where copying should start.

   length: The number of array elements to copy.

  Copy(source: IntPtr,destination: Array[Char],startIndex: int,length: int)

   Copies data from an unmanaged memory pointer to a managed character array.

  

   source: The memory pointer to copy from.

   destination: The array to copy to.

   startIndex: The zero-based index in the destination  array where copying should start.

   length: The number of array elements to copy.

  Copy(source: IntPtr,destination: Array[Byte],startIndex: int,length: int)

   Copies data from an unmanaged memory pointer to a managed 8-bit unsigned integer array.

  

   source: The memory pointer to copy from.

   destination: The array to copy to.

   startIndex: The zero-based index in the destination  array where copying should start.

   length: The number of array elements to copy.

  Copy(source: IntPtr,destination: Array[IntPtr],startIndex: int,length: int)

   Copies data from an unmanaged memory pointer to a managed System.IntPtr array.

  

   source: The memory pointer to copy from.

   destination: The array to copy to.

   startIndex: The zero-based index into the destination array where copying should start.

   length: The number of array elements to copy.

  Copy(source: IntPtr,destination: Array[Single],startIndex: int,length: int)

   Copies data from an unmanaged memory pointer to a managed single-precision floating-point number 

    array.

  

  

   source: The memory pointer to copy from.

   destination: The array to copy to.

   startIndex: The zero-based index in the destination  array where copying should start.

   length: The number of array elements to copy.

  Copy(source: IntPtr,destination: Array[float],startIndex: int,length: int)

   Copies data from an unmanaged memory pointer to a managed double-precision floating-point number 

    array.

  

  

   source: The memory pointer to copy from.

   destination: The array to copy to.

   startIndex: The zero-based index in the destination  array where copying should start.

   length: The number of array elements to copy.

  Copy(source: Array[Int16],startIndex: int,destination: IntPtr,length: int)

   Copies data from a one-dimensional,managed 16-bit signed integer array to an unmanaged memory 

    pointer.

  

  

   source: The one-dimensional array to copy from.

   startIndex: The zero-based index in the source array where copying should start.

   destination: The memory pointer to copy to.

   length: The number of array elements to copy.

  Copy(source: Array[Int64],startIndex: int,destination: IntPtr,length: int)

   Copies data from a one-dimensional,managed 64-bit signed integer array to an unmanaged memory 

    pointer.

  

  

   source: The one-dimensional array to copy from.

   startIndex: The zero-based index in the source array where copying should start.

   destination: The memory pointer to copy to.

   length: The number of array elements to copy.

  Copy(source: Array[int],startIndex: int,destination: IntPtr,length: int)

   Copies data from a one-dimensional,managed 32-bit signed integer array to an unmanaged memory 

    pointer.

  

  

   source: The one-dimensional array to copy from.

   startIndex: The zero-based index in the source array where copying should start.

   destination: The memory pointer to copy to.

   length: The number of array elements to copy.

  Copy(source: Array[Char],startIndex: int,destination: IntPtr,length: int)

   Copies data from a one-dimensional,managed character array to an unmanaged memory pointer.

  

   source: The one-dimensional array to copy from.

   startIndex: The zero-based index in the source array where copying should start.

   destination: The memory pointer to copy to.

   length: The number of array elements to copy.

  Copy(source: Array[Byte],startIndex: int,destination: IntPtr,length: int)

   Copies data from a one-dimensional,managed 8-bit unsigned integer array to an unmanaged memory 

    pointer.

  

  

   source: The one-dimensional array to copy from.

   startIndex: The zero-based index in the source array where copying should start.

   destination: The memory pointer to copy to.

   length: The number of array elements to copy.

  Copy(source: Array[IntPtr],startIndex: int,destination: IntPtr,length: int)

   Copies data from a one-dimensional,managed System.IntPtr array to an unmanaged memory pointer.

  

   source: The one-dimensional array to copy from.

   startIndex: The zero-based index into the source array where copying should start.

   destination: The memory pointer to copy to.

   length: The number of array elements to copy.

  Copy(source: Array[Single],startIndex: int,destination: IntPtr,length: int)

   Copies data from a one-dimensional,managed single-precision floating-point number array to an 

    unmanaged memory pointer.

  

  

   source: The one-dimensional array to copy from.

   startIndex: The zero-based index in the source array where copying should start.

   destination: The memory pointer to copy to.

   length: The number of array elements to copy.

  Copy(source: Array[float],startIndex: int,destination: IntPtr,length: int)

   Copies data from a one-dimensional,managed double-precision floating-point number array to an 

    unmanaged memory pointer.

  

  

   source: The one-dimensional array to copy from.

   startIndex: The zero-based index in the source array where copying should start.

   destination: The memory pointer to copy to.

   length: The number of array elements to copy.
  """
  pass
 @staticmethod
 def CreateAggregatedObject(pOuter,o):
  """
  CreateAggregatedObject[T](pOuter: IntPtr,o: T) -> IntPtr

  CreateAggregatedObject(pOuter: IntPtr,o: object) -> IntPtr

  

   Aggregates a managed object with the specified COM object.

  

   pOuter: The outer IUnknown pointer.

   o: An object to aggregate.

   Returns: The inner IUnknown pointer of the managed object.
  """
  pass
 @staticmethod
 def CreateWrapperOfType(o,t=None):
  """
  CreateWrapperOfType[(T,TWrapper)](o: T) -> TWrapper

  CreateWrapperOfType(o: object,t: Type) -> object

  

   Wraps the specified COM object in an object of the specified type.

  

   o: The object to be wrapped.

   t: The type of wrapper to create.

   Returns: The newly wrapped object that is an instance of the desired type.
  """
  pass
 @staticmethod
 def DestroyStructure(ptr,structuretype=None):
  """
  DestroyStructure[T](ptr: IntPtr)DestroyStructure(ptr: IntPtr,structuretype: Type)

   Frees all substructures that the specified unmanaged memory block points to.

  

   ptr: A pointer to an unmanaged block of memory.

   structuretype: Type of a formatted class. This provides the layout information necessary to delete the buffer 

    in the ptr parameter.
  """
  pass
 @staticmethod
 def FinalReleaseComObject(o):
  """
  FinalReleaseComObject(o: object) -> int

  

   Releases all references to a Runtime Callable Wrapper (RCW) by setting its reference count to 0.

  

   o: The RCW to be released.

   Returns: The new value of the reference count of the RCW associated with the oparameter,which is 0 

    (zero) if the release is successful.
  """
  pass
 @staticmethod
 def FreeBSTR(ptr):
  """
  FreeBSTR(ptr: IntPtr)

   Frees a BSTR using the COM SysFreeString function.

  

   ptr: The address of the BSTR to be freed.
  """
  pass
 @staticmethod
 def FreeCoTaskMem(ptr):
  """
  FreeCoTaskMem(ptr: IntPtr)

   Frees a block of memory allocated by the unmanaged COM task memory allocator.

  

   ptr: The address of the memory to be freed.
  """
  pass
 @staticmethod
 def FreeHGlobal(hglobal):
  """
  FreeHGlobal(hglobal: IntPtr)

   Frees memory previously allocated from the unmanaged memory of the process.

  

   hglobal: The handle returned by the original matching call to 

    System.Runtime.InteropServices.Marshal.AllocHGlobal(System.IntPtr).
  """
  pass
 @staticmethod
 def GenerateGuidForType(type):
  """
  GenerateGuidForType(type: Type) -> Guid

  

   Returns the globally unique identifier (GUID) for the specified type,or generates a GUID using 

    the algorithm used by the Type Library Exporter (Tlbexp.exe).

  

  

   type: The type to generate a GUID for.

   Returns: An identifier for the specified type.
  """
  pass
 @staticmethod
 def GenerateProgIdForType(type):
  """
  GenerateProgIdForType(type: Type) -> str

  

   Returns a programmatic identifier (ProgID) for the specified type.

  

   type: The type to get a ProgID for.

   Returns: The ProgID of the specified type.
  """
  pass
 @staticmethod
 def GetActiveObject(progID):
  """
  GetActiveObject(progID: str) -> object

  

   Obtains a running instance of the specified object from the running object table (ROT).

  

   progID: The programmatic identifier (ProgID) of the object that was requested.

   Returns: The object that was requested; otherwise null. You can cast this object to any COM interface 

    that it supports.
  """
  pass
 @staticmethod
 def GetComInterfaceForObject(o,T=None,mode=None):
  """
  GetComInterfaceForObject(o: object,T: Type,mode: CustomQueryInterfaceMode) -> IntPtr

  

   Returns a pointer to an IUnknown interface that represents the specified interface on the 

    specified object. Custom query interface access is controlled by the specified customization 

    mode.

  

  

   o: The object that provides the interface.

   T: The type of interface that is requested.

   mode: One of the enumeration values that indicates whether to apply an IUnknown::QueryInterface 

    customization that is supplied by an System.Runtime.InteropServices.ICustomQueryInterface.

  

   Returns: The interface pointer that represents the interface for the object.

  GetComInterfaceForObject[(T,TInterface)](o: T) -> IntPtr

  GetComInterfaceForObject(o: object,T: Type) -> IntPtr

  

   Returns a pointer to an IUnknown interface that represents the specified interface on the 

    specified object. Custom query interface access is enabled by default.

  

  

   o: The object that provides the interface.

   T: The type of interface that is requested.

   Returns: The interface pointer that represents the specified interface for the object.
  """
  pass
 @staticmethod
 def GetComInterfaceForObjectInContext(o,t):
  """
  GetComInterfaceForObjectInContext(o: object,t: Type) -> IntPtr

  

   Returns an interface pointer that represents the specified interface for an object,if the 

    caller is in the same context as that object.

  

  

   o: The object that provides the interface.

   t: The type of interface that is requested.

   Returns: The interface pointer specified by t that represents the interface for the specified object,or 

    null if the caller is not in the same context as the object.
  """
  pass
 @staticmethod
 def GetComObjectData(obj,key):
  """
  GetComObjectData(obj: object,key: object) -> object

  

   Retrieves data that is referenced by the specified key from the specified COM object.

  

   obj: The COM object that contains the data that you want.

   key: The key in the internal hash table of obj to retrieve the data from.

   Returns: The data represented by the key parameter in the internal hash table of the obj parameter.
  """
  pass
 @staticmethod
 def GetComSlotForMethodInfo(m):
  """
  GetComSlotForMethodInfo(m: MemberInfo) -> int

  

   Retrieves the virtual function table (v-table or VTBL) slot for a specified 

    System.Reflection.MemberInfo type when that type is exposed to COM.

  

  

   m: An object that represents an interface method.

   Returns: The VTBL slot m identifier when it is exposed to COM.
  """
  pass
 @staticmethod
 def GetDelegateForFunctionPointer(ptr,t=None):
  """
  GetDelegateForFunctionPointer[TDelegate](ptr: IntPtr) -> TDelegate

  GetDelegateForFunctionPointer(ptr: IntPtr,t: Type) -> Delegate

  

   Converts an unmanaged function pointer to a delegate.

  

   ptr: The unmanaged function pointer to be converted.

   t: The type of the delegate to be returned.

   Returns: A delegate instance that can be cast to the appropriate delegate type.
  """
  pass
 @staticmethod
 def GetEndComSlot(t):
  """
  GetEndComSlot(t: Type) -> int

  

   Retrieves the last slot in the virtual function table (v-table or VTBL) of a type when exposed 

    to COM.

  

  

   t: A type that represents an interface or class.

   Returns: The last VTBL slot of the interface when exposed to COM. If the t parameter is a class,the 

    returned VTBL slot is the last slot in the interface that is generated from the class.
  """
  pass
 @staticmethod
 def GetExceptionCode():
  """
  GetExceptionCode() -> int

  

   Retrieves a code that identifies the type of the exception that occurred.

   Returns: The type of the exception.
  """
  pass
 @staticmethod
 def GetExceptionForHR(errorCode,errorInfo=None):
  """
  GetExceptionForHR(errorCode: int,errorInfo: IntPtr) -> Exception

  

   Converts the specified HRESULT error code to a corresponding System.Exception object,with 

    additional error information passed in an IErrorInfo interface for the exception object.

  

  

   errorCode: The HRESULT to be converted.

   errorInfo: A pointer to the IErrorInfo interface that provides more information about the error. You can 

    specify IntPtr(0) to use the current IErrorInfo interface,or IntPtr(-1) to ignore the current 

    IErrorInfo interface and construct the exception just from the error code.

  

   Returns: An object that represents the converted HRESULT and information obtained from errorInfo.

  GetExceptionForHR(errorCode: int) -> Exception

  

   Converts the specified HRESULT error code to a corresponding System.Exception object.

  

   errorCode: The HRESULT to be converted.

   Returns: An object that represents the converted HRESULT.
  """
  pass
 @staticmethod
 def GetExceptionPointers():
  """
  GetExceptionPointers() -> IntPtr

  

   Retrieves a computer-independent description of an exception,and information about the state 

    that existed for the thread when the exception occurred.

  

   Returns: A pointer to an EXCEPTION_POINTERS structure.
  """
  pass
 @staticmethod
 def GetFunctionPointerForDelegate(d):
  """
  GetFunctionPointerForDelegate[TDelegate](d: TDelegate) -> IntPtr

  GetFunctionPointerForDelegate(d: Delegate) -> IntPtr

  

   Converts a delegate into a function pointer that is callable from unmanaged code.

  

   d: The delegate to be passed to unmanaged code.

   Returns: A value that can be passed to unmanaged code,which,in turn,can use it to call the underlying 

    managed delegate.
  """
  pass
 @staticmethod
 def GetHINSTANCE(m):
  """
  GetHINSTANCE(m: Module) -> IntPtr

  

   Returns the instance handle (HINSTANCE) for the specified module.

  

   m: The module whose HINSTANCE is desired.

   Returns: The HINSTANCE for m; or -1 if the module does not have an HINSTANCE.
  """
  pass
 @staticmethod
 def GetHRForException(e):
  """
  GetHRForException(e: Exception) -> int

  

   Converts the specified exception to an HRESULT.

  

   e: The exception to convert to an HRESULT.

   Returns: The HRESULT mapped to the supplied exception.
  """
  pass
 @staticmethod
 def GetHRForLastWin32Error():
  """
  GetHRForLastWin32Error() -> int

  

   Returns the HRESULT corresponding to the last error incurred by Win32 code executed using 

    System.Runtime.InteropServices.Marshal.

  

   Returns: The HRESULT corresponding to the last Win32 error code.
  """
  pass
 @staticmethod
 def GetIDispatchForObject(o):
  """
  GetIDispatchForObject(o: object) -> IntPtr

  

   Returns an IDispatch interface from a managed object.

  

   o: The object whose IDispatch interface is requested.

   Returns: The IDispatch pointer for the o parameter.
  """
  pass
 @staticmethod
 def GetIDispatchForObjectInContext(o):
  """
  GetIDispatchForObjectInContext(o: object) -> IntPtr

  

   Returns an IDispatch interface pointer from a managed object,if the caller is in the same 

    context as that object.

  

  

   o: The object whose IDispatch interface is requested.

   Returns: The IDispatch interface pointer for the specified object,or null if the caller is not in the 

    same context as the specified object.
  """
  pass
 @staticmethod
 def GetITypeInfoForType(t):
  """
  GetITypeInfoForType(t: Type) -> IntPtr

  

   Returns a System.Runtime.InteropServices.ComTypes.ITypeInfo interface from a managed type.

  

   t: The type whose ITypeInfo interface is being requested.

   Returns: A pointer to the ITypeInfo interface for the t parameter.
  """
  pass
 @staticmethod
 def GetIUnknownForObject(o):
  """
  GetIUnknownForObject(o: object) -> IntPtr

  

   Returns an IUnknown interface from a managed object.

  

   o: The object whose IUnknown interface is requested.

   Returns: The IUnknown pointer for the o parameter.
  """
  pass
 @staticmethod
 def GetIUnknownForObjectInContext(o):
  """
  GetIUnknownForObjectInContext(o: object) -> IntPtr

  

   Returns an IUnknown interface from a managed object,if the caller is in the same context as 

    that object.

  

  

   o: The object whose IUnknown interface is requested.

   Returns: The IUnknown pointer for the specified object,or null if the caller is not in the same context 

    as the specified object.
  """
  pass
 @staticmethod
 def GetLastWin32Error():
  """
  GetLastWin32Error() -> int

  

   Returns the error code returned by the last unmanaged function that was called using platform 

    invoke that has the System.Runtime.InteropServices.DllImportAttribute.SetLastError flag set.

  

   Returns: The last error code set by a call to the Win32 SetLastError function.
  """
  pass
 @staticmethod
 def GetManagedThunkForUnmanagedMethodPtr(pfnMethodToWrap,pbSignature,cbSignature):
  """
  GetManagedThunkForUnmanagedMethodPtr(pfnMethodToWrap: IntPtr,pbSignature: IntPtr,cbSignature: int) -> IntPtr

  

   Gets a pointer to a runtime-generated function that marshals a call from managed to unmanaged 

    code.

  

  

   pfnMethodToWrap: A pointer to the method to marshal.

   pbSignature: A pointer to the method signature.

   cbSignature: The number of bytes in pbSignature.

   Returns: A pointer to the function that will marshal a call from the pfnMethodToWrap parameter to 

    unmanaged code.
  """
  pass
 @staticmethod
 def GetMethodInfoForComSlot(t,slot,memberType):
  """
  GetMethodInfoForComSlot(t: Type,slot: int,memberType: ComMemberType) -> (MemberInfo,ComMemberType)

  

   Retrieves a System.Reflection.MemberInfo object for the specified virtual function table 

    (v-table or VTBL) slot.

  

  

   t: The type for which the System.Reflection.MemberInfo is to be retrieved.

   slot: The VTBL slot.

   memberType: On successful return,one of the enumeration values that specifies the type of the member.

   Returns: The object that represents the member at the specified VTBL slot.
  """
  pass
 @staticmethod
 def GetNativeVariantForObject(obj,pDstNativeVariant):
  """
  GetNativeVariantForObject[T](obj: T,pDstNativeVariant: IntPtr)GetNativeVariantForObject(obj: object,pDstNativeVariant: IntPtr)

   Converts an object to a COM VARIANT.

  

   obj: The object for which to get a COM VARIANT.

   pDstNativeVariant: A pointer to receive the VARIANT that corresponds to the obj parameter.
  """
  pass
 @staticmethod
 def GetObjectForIUnknown(pUnk):
  """
  GetObjectForIUnknown(pUnk: IntPtr) -> object

  

   Returns an instance of a type that represents a COM object by a pointer to its IUnknown 

    interface.

  

  

   pUnk: A pointer to the IUnknown interface.

   Returns: An object that represents the specified unmanaged COM object.
  """
  pass
 @staticmethod
 def GetObjectForNativeVariant(pSrcNativeVariant):
  """
  GetObjectForNativeVariant[T](pSrcNativeVariant: IntPtr) -> T

  

   Converts a COM VARIANT to an object.

  

   pSrcNativeVariant: A pointer to a COM VARIANT.

   Returns: An object that corresponds to the pSrcNativeVariant parameter.

  GetObjectForNativeVariant(pSrcNativeVariant: IntPtr) -> object

  

   Converts a COM VARIANT to an object.

  

   pSrcNativeVariant: A pointer to a COM VARIANT.

   Returns: An object that corresponds to the pSrcNativeVariant parameter.
  """
  pass
 @staticmethod
 def GetObjectsForNativeVariants(aSrcNativeVariant,cVars):
  """
  GetObjectsForNativeVariants[T](aSrcNativeVariant: IntPtr,cVars: int) -> Array[T]

  

   Converts an array of COM VARIANTs to an array of objects.

  

   aSrcNativeVariant: A pointer to the first element of an array of COM VARIANTs.

   cVars: The count of COM VARIANTs in aSrcNativeVariant.

   Returns: An object array that corresponds to aSrcNativeVariant.

  GetObjectsForNativeVariants(aSrcNativeVariant: IntPtr,cVars: int) -> Array[object]

  

   Converts an array of COM VARIANTs to an array of objects.

  

   aSrcNativeVariant: A pointer to the first element of an array of COM VARIANTs.

   cVars: The count of COM VARIANTs in aSrcNativeVariant.

   Returns: An object array that corresponds to aSrcNativeVariant.
  """
  pass
 @staticmethod
 def GetStartComSlot(t):
  """
  GetStartComSlot(t: Type) -> int

  

   Gets the first slot in the virtual function table (v-table or VTBL) that contains user-defined 

    methods.

  

  

   t: A type that represents an interface.

   Returns: The first VTBL slot that contains user-defined methods. The first slot is 3 if the interface is 

    based on IUnknown,and 7 if the interface is based on IDispatch.
  """
  pass
 @staticmethod
 def GetThreadFromFiberCookie(cookie):
  """
  GetThreadFromFiberCookie(cookie: int) -> Thread

  

   Converts a fiber cookie into the corresponding System.Threading.Thread instance.

  

   cookie: An integer that represents a fiber cookie.

   Returns: A thread that corresponds to the cookie parameter.
  """
  pass
 @staticmethod
 def GetTypedObjectForIUnknown(pUnk,t):
  """
  GetTypedObjectForIUnknown(pUnk: IntPtr,t: Type) -> object

  

   Returns a managed object of a specified type that represents a COM object.

  

   pUnk: A pointer to the IUnknown interface of the unmanaged object.

   t: The type of the requested managed class.

   Returns: An instance of the class corresponding to the System.Type object that represents the requested 

    unmanaged COM object.
  """
  pass
 @staticmethod
 def GetTypeForITypeInfo(piTypeInfo):
  """
  GetTypeForITypeInfo(piTypeInfo: IntPtr) -> Type

  

   Converts an unmanaged ITypeInfo object into a managed System.Type object.

  

   piTypeInfo: The ITypeInfo interface to marshal.

   Returns: A managed type that represents the unmanaged ITypeInfo object.
  """
  pass
 @staticmethod
 def GetTypeFromCLSID(clsid):
  """ GetTypeFromCLSID(clsid: Guid) -> Type """
  pass
 @staticmethod
 def GetTypeInfoName(*__args):
  """
  GetTypeInfoName(typeInfo: ITypeInfo) -> str

  

   Retrieves the name of the type represented by an ITypeInfo object.

  

   typeInfo: An object that represents an ITypeInfo pointer.

   Returns: The name of the type that the typeInfo parameter points to.

  GetTypeInfoName(pTI: UCOMITypeInfo) -> str

  

   Retrieves the name of the type represented by an ITypeInfo object.

  

   pTI: An object that represents an ITypeInfo pointer.

   Returns: The name of the type that the pTI parameter points to.
  """
  pass
 @staticmethod
 def GetTypeLibGuid(*__args):
  """
  GetTypeLibGuid(typelib: ITypeLib) -> Guid

  

   Retrieves the library identifier (LIBID) of a type library.

  

   typelib: The type library whose LIBID is to be retrieved.

   Returns: The LIBID of the specified type library.

  GetTypeLibGuid(pTLB: UCOMITypeLib) -> Guid

  

   Retrieves the library identifier (LIBID) of a type library.

  

   pTLB: The type library whose LIBID is to be retrieved.

   Returns: The LIBID of the type library that the pTLB parameter points to.
  """
  pass
 @staticmethod
 def GetTypeLibGuidForAssembly(asm):
  """
  GetTypeLibGuidForAssembly(asm: Assembly) -> Guid

  

   Retrieves the library identifier (LIBID) that is assigned to a type library when it was exported 

    from the specified assembly.

  

  

   asm: The assembly from which the type library was exported.

   Returns: The LIBID that is assigned to a type library when it is exported from the specified assembly.
  """
  pass
 @staticmethod
 def GetTypeLibLcid(*__args):
  """
  GetTypeLibLcid(typelib: ITypeLib) -> int

  

   Retrieves the LCID of a type library.

  

   typelib: The type library whose LCID is to be retrieved.

   Returns: The LCID of the type library that the typelib parameter points to.

  GetTypeLibLcid(pTLB: UCOMITypeLib) -> int

  

   Retrieves the LCID of a type library.

  

   pTLB: The type library whose LCID is to be retrieved.

   Returns: The LCID of the type library that the pTLB parameter points to.
  """
  pass
 @staticmethod
 def GetTypeLibName(*__args):
  """
  GetTypeLibName(typelib: ITypeLib) -> str

  

   Retrieves the name of a type library.

  

   typelib: The type library whose name is to be retrieved.

   Returns: The name of the type library that the typelib parameter points to.

  GetTypeLibName(pTLB: UCOMITypeLib) -> str

  

   Retrieves the name of a type library.

  

   pTLB: The type library whose name is to be retrieved.

   Returns: The name of the type library that the pTLB parameter points to.
  """
  pass
 @staticmethod
 def GetTypeLibVersionForAssembly(inputAssembly,majorVersion,minorVersion):
  """
  GetTypeLibVersionForAssembly(inputAssembly: Assembly) -> (int,int)

  

   Retrieves the version number of a type library that will be exported from the specified assembly.

  

   inputAssembly: A managed assembly.
  """
  pass
 @staticmethod
 def GetUniqueObjectForIUnknown(unknown):
  """
  GetUniqueObjectForIUnknown(unknown: IntPtr) -> object

  

   Creates a unique Runtime Callable Wrapper (RCW) object for a given IUnknown interface.

  

   unknown: A managed pointer to an IUnknown interface.

   Returns: A unique RCW for the specified IUnknown interface.
  """
  pass
 @staticmethod
 def GetUnmanagedThunkForManagedMethodPtr(pfnMethodToWrap,pbSignature,cbSignature):
  """
  GetUnmanagedThunkForManagedMethodPtr(pfnMethodToWrap: IntPtr,pbSignature: IntPtr,cbSignature: int) -> IntPtr

  

   Gets a pointer to a runtime-generated function that marshals a call from unmanaged to managed 

    code.

  

  

   pfnMethodToWrap: A pointer to the method to marshal.

   pbSignature: A pointer to the method signature.

   cbSignature: The number of bytes in pbSignature.

   Returns: A pointer to a function that will marshal a call from pfnMethodToWrap to managed code.
  """
  pass
 @staticmethod
 def IsComObject(o):
  """
  IsComObject(o: object) -> bool

  

   Indicates whether a specified object represents a COM object.

  

   o: The object to check.

   Returns: true if the o parameter is a COM type; otherwise,false.
  """
  pass
 @staticmethod
 def IsTypeVisibleFromCom(t):
  """
  IsTypeVisibleFromCom(t: Type) -> bool

  

   Indicates whether a type is visible to COM clients.

  

   t: The type to check for COM visibility.

   Returns: true if the type is visible to COM; otherwise,false.
  """
  pass
 @staticmethod
 def NumParamBytes(m):
  """
  NumParamBytes(m: MethodInfo) -> int

  

   Calculates the number of bytes in unmanaged memory that are required to hold the parameters for 

    the specified method.

  

  

   m: The method to be checked.

   Returns: The number of bytes required to represent the method parameters in unmanaged memory.
  """
  pass
 @staticmethod
 def OffsetOf(*__args):
  """
  OffsetOf[T](fieldName: str) -> IntPtr

  OffsetOf(t: Type,fieldName: str) -> IntPtr

  

   Returns the field offset of the unmanaged form of the managed class.

  

   t: A value type or formatted reference type that specifies the managed class. You must apply the 

    System.Runtime.InteropServices.StructLayoutAttribute to the class.

  

   fieldName: The field within the t parameter.

   Returns: The offset,in bytes,for the fieldName parameter within the specified class that is declared by 

    platform invoke.
  """
  pass
 @staticmethod
 def Prelink(m):
  """
  Prelink(m: MethodInfo)

   Executes one-time method setup tasks without calling the method.

  

   m: The method to be checked.
  """
  pass
 @staticmethod
 def PrelinkAll(c):
  """
  PrelinkAll(c: Type)

   Performs a pre-link check for all methods on a class.

  

   c: The class whose methods are to be checked.
  """
  pass
 @staticmethod
 def PtrToStringAnsi(ptr,len=None):
  """
  PtrToStringAnsi(ptr: IntPtr,len: int) -> str

  

   Allocates a managed System.String,copies a specified number of characters from an unmanaged 

    ANSI string into it,and widens each ANSI character to Unicode.

  

  

   ptr: The address of the first character of the unmanaged string.

   len: The byte count of the input string to copy.

   Returns: A managed string that holds a copy of the native ANSI string if the value of the ptr parameter 

    is not null; otherwise,this method returns null.

  

  PtrToStringAnsi(ptr: IntPtr) -> str

  

   Copies all characters up to the first null character from an unmanaged ANSI string to a managed 

    System.String,and widens each ANSI character to Unicode.

  

  

   ptr: The address of the first character of the unmanaged string.

   Returns: A managed string that holds a copy of the unmanaged ANSI string. If ptr is null,the method 

    returns a null string.
  """
  pass
 @staticmethod
 def PtrToStringAuto(ptr,len=None):
  """
  PtrToStringAuto(ptr: IntPtr) -> str

  

   Allocates a managed System.String and copies all characters up to the first null character from 

    a string stored in unmanaged memory into it.

  

  

   ptr: For Unicode platforms,the address of the first Unicode character.-or- For ANSI plaforms,the 

    address of the first ANSI character.

  

   Returns: A managed string that holds a copy of the unmanaged string if the value of the ptr parameter is 

    not null; otherwise,this method returns null.

  

  PtrToStringAuto(ptr: IntPtr,len: int) -> str

  

   Allocates a managed System.String and copies the specified number of characters from a string 

    stored in unmanaged memory into it.

  

  

   ptr: For Unicode platforms,the address of the first Unicode character.-or- For ANSI plaforms,the 

    address of the first ANSI character.

  

   len: The number of characters to copy.

   Returns: A managed string that holds a copy of the native string if the value of the ptr parameter is not 

    null; otherwise,this method returns null.
  """
  pass
 @staticmethod
 def PtrToStringBSTR(ptr):
  """
  PtrToStringBSTR(ptr: IntPtr) -> str

  

   Allocates a managed System.String and copies a BSTR Data Type string stored in unmanaged memory 

    into it.

  

  

   ptr: The address of the first character of the unmanaged string.

   Returns: A managed string that holds a copy of the unmanaged string if the value of the ptr parameter is 

    not null; otherwise,this method returns null.
  """
  pass
 @staticmethod
 def PtrToStringUni(ptr,len=None):
  """
  PtrToStringUni(ptr: IntPtr) -> str

  

   Allocates a managed System.String and copies all characters up to the first null character from 

    an unmanaged Unicode string into it.

  

  

   ptr: The address of the first character of the unmanaged string.

   Returns: A managed string that holds a copy of the unmanaged string if the value of the ptr parameter is 

    not null; otherwise,this method returns null.

  

  PtrToStringUni(ptr: IntPtr,len: int) -> str

  

   Allocates a managed System.String and copies a specified number of characters from an unmanaged 

    Unicode string into it.

  

  

   ptr: The address of the first character of the unmanaged string.

   len: The number of Unicode characters to copy.

   Returns: A managed string that holds a copy of the unmanaged string if the value of the ptr parameter is 

    not null; otherwise,this method returns null.
  """
  pass
 @staticmethod
 def PtrToStructure(ptr,*__args):
  """
  PtrToStructure(ptr: IntPtr,structureType: Type) -> object

  

   Marshals data from an unmanaged block of memory to a newly allocated managed object of the 

    specified type.

  

  

   ptr: A pointer to an unmanaged block of memory.

   structureType: The type of object to be created. This object must represent a formatted class or a structure.

   Returns: A managed object containing the data pointed to by the ptr parameter.

  PtrToStructure[T](ptr: IntPtr) -> T

  PtrToStructure(ptr: IntPtr,structure: object)

   Marshals data from an unmanaged block of memory to a managed object.

  

   ptr: A pointer to an unmanaged block of memory.

   structure: The object to which the data is to be copied. This must be an instance of a formatted class.

  PtrToStructure[T](ptr: IntPtr,structure: T)
  """
  pass
 @staticmethod
 def QueryInterface(pUnk,iid,ppv):
  """
  QueryInterface(pUnk: IntPtr,iid: Guid) -> (int,Guid,IntPtr)

  

   Requests a pointer to a specified interface from a COM object.

  

   pUnk: The interface to be queried.

   iid: The interface identifier (IID) of the requested interface.

   Returns: An HRESULT that indicates the success or failure of the call.
  """
  pass
 @staticmethod
 def ReadByte(ptr,ofs=None):
  """
  ReadByte(ptr: IntPtr) -> Byte

  

   Reads a single byte from unmanaged memory.

  

   ptr: The address in unmanaged memory from which to read.

   Returns: The byte read from unmanaged memory.

  ReadByte(ptr: IntPtr,ofs: int) -> Byte

  

   Reads a single byte at a given offset (or index) from unmanaged memory.

  

   ptr: The base address in unmanaged memory from which to read.

   ofs: An additional byte offset,which is added to the ptr parameter before reading.

   Returns: The byte read from unmanaged memory at the given offset.

  ReadByte(ptr: object,ofs: int) -> Byte

  

   Reads a single byte at a given offset (or index) from unmanaged memory.

  

   ptr: The base address in unmanaged memory of the source object.

   ofs: An additional byte offset,which is added to the ptr parameter before reading.

   Returns: The byte read from unmanaged memory at the given offset.
  """
  pass
 @staticmethod
 def ReadInt16(ptr,ofs=None):
  """
  ReadInt16(ptr: IntPtr) -> Int16

  

   Reads a 16-bit signed integer from unmanaged memory.

  

   ptr: The address in unmanaged memory from which to read.

   Returns: The 16-bit signed integer read from unmanaged memory.

  ReadInt16(ptr: IntPtr,ofs: int) -> Int16

  

   Reads a 16-bit signed integer at a given offset from unmanaged memory.

  

   ptr: The base address in unmanaged memory from which to read.

   ofs: An additional byte offset,which is added to the ptr parameter before reading.

   Returns: The 16-bit signed integer read from unmanaged memory at the given offset.

  ReadInt16(ptr: object,ofs: int) -> Int16

  

   Reads a 16-bit signed integer at a given offset from unmanaged memory.

  

   ptr: The base address in unmanaged memory of the source object.

   ofs: An additional byte offset,which is added to the ptr parameter before reading.

   Returns: The 16-bit signed integer read from unmanaged memory at the given offset.
  """
  pass
 @staticmethod
 def ReadInt32(ptr,ofs=None):
  """
  ReadInt32(ptr: IntPtr) -> int

  

   Reads a 32-bit signed integer from unmanaged memory.

  

   ptr: The address in unmanaged memory from which to read.

   Returns: The 32-bit signed integer read from unmanaged memory.

  ReadInt32(ptr: IntPtr,ofs: int) -> int

  

   Reads a 32-bit signed integer at a given offset from unmanaged memory.

  

   ptr: The base address in unmanaged memory from which to read.

   ofs: An additional byte offset,which is added to the ptr parameter before reading.

   Returns: The 32-bit signed integer read from unmanaged memory.

  ReadInt32(ptr: object,ofs: int) -> int

  

   Reads a 32-bit signed integer at a given offset from unmanaged memory.

  

   ptr: The base address in unmanaged memory of the source object.

   ofs: An additional byte offset,which is added to the ptr parameter before reading.

   Returns: The 32-bit signed integer read from unmanaged memory at the given offset.
  """
  pass
 @staticmethod
 def ReadInt64(ptr,ofs=None):
  """
  ReadInt64(ptr: IntPtr) -> Int64

  

   Reads a 64-bit signed integer from unmanaged memory.

  

   ptr: The address in unmanaged memory from which to read.

   Returns: The 64-bit signed integer read from unmanaged memory.

  ReadInt64(ptr: IntPtr,ofs: int) -> Int64

  

   Reads a 64-bit signed integer at a given offset from unmanaged memory.

  

   ptr: The base address in unmanaged memory from which to read.

   ofs: An additional byte offset,which is added to the ptr parameter before reading.

   Returns: The 64-bit signed integer read from unmanaged memory at the given offset.

  ReadInt64(ptr: object,ofs: int) -> Int64

  

   Reads a 64-bit signed integer at a given offset from unmanaged memory.

  

   ptr: The base address in unmanaged memory of the source object.

   ofs: An additional byte offset,which is added to the ptr parameter before reading.

   Returns: The 64-bit signed integer read from unmanaged memory at the given offset.
  """
  pass
 @staticmethod
 def ReadIntPtr(ptr,ofs=None):
  """
  ReadIntPtr(ptr: IntPtr) -> IntPtr

  

   Reads a processor native-sized integer from unmanaged memory.

  

   ptr: The address in unmanaged memory from which to read.

   Returns: The integer read from unmanaged memory. A 32 bit integer is returned on 32 bit machines and a 64 

    bit integer is returned on 64 bit machines.

  

  ReadIntPtr(ptr: IntPtr,ofs: int) -> IntPtr

  

   Reads a processor native sized integer at a given offset from unmanaged memory.

  

   ptr: The base address in unmanaged memory from which to read.

   ofs: An additional byte offset,which is added to the ptr parameter before reading.

   Returns: The integer read from unmanaged memory at the given offset.

  ReadIntPtr(ptr: object,ofs: int) -> IntPtr

  

   Reads a processor native sized integer from unmanaged memory.

  

   ptr: The base address in unmanaged memory of the source object.

   ofs: An additional byte offset,which is added to the ptr parameter before reading.

   Returns: The integer read from unmanaged memory at the given offset.
  """
  pass
 @staticmethod
 def ReAllocCoTaskMem(pv,cb):
  """
  ReAllocCoTaskMem(pv: IntPtr,cb: int) -> IntPtr

  

   Resizes a block of memory previously allocated with 

    System.Runtime.InteropServices.Marshal.AllocCoTaskMem(System.Int32).

  

  

   pv: A pointer to memory allocated with 

    System.Runtime.InteropServices.Marshal.AllocCoTaskMem(System.Int32).

  

   cb: The new size of the allocated block.

   Returns: An integer representing the address of the reallocated block of memory. This memory must be 

    released with System.Runtime.InteropServices.Marshal.FreeCoTaskMem(System.IntPtr).
  """
  pass
 @staticmethod
 def ReAllocHGlobal(pv,cb):
  """
  ReAllocHGlobal(pv: IntPtr,cb: IntPtr) -> IntPtr

  

   Resizes a block of memory previously allocated with 

    System.Runtime.InteropServices.Marshal.AllocHGlobal(System.IntPtr).

  

  

   pv: A pointer to memory allocated with 

    System.Runtime.InteropServices.Marshal.AllocHGlobal(System.IntPtr).

  

   cb: The new size of the allocated block. This is not a pointer; it is the byte count you are 

    requesting,cast to type System.IntPtr. If you pass a pointer,it is treated as a size.

  

   Returns: A pointer to the reallocated memory. This memory must be released using 

    System.Runtime.InteropServices.Marshal.FreeHGlobal(System.IntPtr).
  """
  pass
 @staticmethod
 def Release(pUnk):
  """
  Release(pUnk: IntPtr) -> int

  

   Decrements the reference count on the specified interface.

  

   pUnk: The interface to release.

   Returns: The new value of the reference count on the interface specified by the pUnk parameter.
  """
  pass
 @staticmethod
 def ReleaseComObject(o):
  """
  ReleaseComObject(o: object) -> int

  

   Decrements the reference count of the specified Runtime Callable Wrapper (RCW) associated with 

    the specified COM object.

  

  

   o: The COM object to release.

   Returns: The new value of the reference count of the RCW associated with o. This value is typically zero 

    since the RCW keeps just one reference to the wrapped COM object regardless of the number of 

    managed clients calling it.
  """
  pass
 @staticmethod
 def ReleaseThreadCache():
  """
  ReleaseThreadCache()

   Releases the thread cache.
  """
  pass
 @staticmethod
 def SecureStringToBSTR(s):
  """
  SecureStringToBSTR(s: SecureString) -> IntPtr

  

   Allocates a BSTR Data Type and copies the contents of a managed System.Security.SecureString 

    object into it.

  

  

   s: The managed object to copy.

   Returns: The address,in unmanaged memory,where the s parameter was copied to,or 0 if a null object was 

    supplied.
  """
  pass
 @staticmethod
 def SecureStringToCoTaskMemAnsi(s):
  """
  SecureStringToCoTaskMemAnsi(s: SecureString) -> IntPtr

  

   Copies the contents of a managed System.Security.SecureString object to a block of memory 

    allocated from the unmanaged COM task allocator.

  

  

   s: The managed object to copy.

   Returns: The address,in unmanaged memory,where the s parameter was copied to,or 0 if a null object was 

    supplied.
  """
  pass
 @staticmethod
 def SecureStringToCoTaskMemUnicode(s):
  """
  SecureStringToCoTaskMemUnicode(s: SecureString) -> IntPtr

  

   Copies the contents of a managed System.Security.SecureString object to a block of memory 

    allocated from the unmanaged COM task allocator.

  

  

   s: The managed object to copy.

   Returns: The address,in unmanaged memory,where the s parameter was copied to,or 0 if a null object was 

    supplied.
  """
  pass
 @staticmethod
 def SecureStringToGlobalAllocAnsi(s):
  """
  SecureStringToGlobalAllocAnsi(s: SecureString) -> IntPtr

  

   Copies the contents of a managed System.Security.SecureString into unmanaged memory,converting 

    into ANSI format as it copies.

  

  

   s: The managed object to copy.

   Returns: The address,in unmanaged memory,to where the s parameter was copied,or 0 if a null object was 

    supplied.
  """
  pass
 @staticmethod
 def SecureStringToGlobalAllocUnicode(s):
  """
  SecureStringToGlobalAllocUnicode(s: SecureString) -> IntPtr

  

   Copies the contents of a managed System.Security.SecureString object into unmanaged memory.

  

   s: The managed object to copy.

   Returns: The address,in unmanaged memory,where s was copied,or 0 if s is a 

    System.Security.SecureString object whose length is 0.
  """
  pass
 @staticmethod
 def SetComObjectData(obj,key,data):
  """
  SetComObjectData(obj: object,key: object,data: object) -> bool

  

   Sets data referenced by the specified key in the specified COM object.

  

   obj: The COM object in which to store the data.

   key: The key in the internal hash table of the COM object in which to store the data.

   data: The data to set.

   Returns: true if the data was set successfully; otherwise,false.
  """
  pass
 @staticmethod
 def SizeOf(*__args):
  """
  SizeOf(t: Type) -> int

  

   Returns the size of an unmanaged type in bytes.

  

   t: The type whose size is to be returned.

   Returns: The size of the specified type in unmanaged code.

  SizeOf[T]() -> int

  SizeOf(structure: object) -> int

  

   Returns the unmanaged size of an object in bytes.

  

   structure: The object whose size is to be returned.

   Returns: The size of the specified object in unmanaged code.

  SizeOf[T](structure: T) -> int
  """
  pass
 @staticmethod
 def StringToBSTR(s):
  """
  StringToBSTR(s: str) -> IntPtr

  

   Allocates a BSTR Data Type and copies the contents of a managed System.String into it.

  

   s: The managed string to be copied.

   Returns: An unmanaged pointer to the BSTR,or 0 if s is null.
  """
  pass
 @staticmethod
 def StringToCoTaskMemAnsi(s):
  """
  StringToCoTaskMemAnsi(s: str) -> IntPtr

  

   Copies the contents of a managed System.String to a block of memory allocated from the unmanaged 

    COM task allocator.

  

  

   s: A managed string to be copied.

   Returns: An integer representing a pointer to the block of memory allocated for the string,or 0 if s is 

    null.
  """
  pass
 @staticmethod
 def StringToCoTaskMemAuto(s):
  """
  StringToCoTaskMemAuto(s: str) -> IntPtr

  

   Copies the contents of a managed System.String to a block of memory allocated from the unmanaged 

    COM task allocator.

  

  

   s: A managed string to be copied.

   Returns: The allocated memory block,or 0 if s is null.
  """
  pass
 @staticmethod
 def StringToCoTaskMemUni(s):
  """
  StringToCoTaskMemUni(s: str) -> IntPtr

  

   Copies the contents of a managed System.String to a block of memory allocated from the unmanaged 

    COM task allocator.

  

  

   s: A managed string to be copied.

   Returns: An integer representing a pointer to the block of memory allocated for the string,or 0 if s is 

    null.
  """
  pass
 @staticmethod
 def StringToHGlobalAnsi(s):
  """
  StringToHGlobalAnsi(s: str) -> IntPtr

  

   Copies the contents of a managed System.String into unmanaged memory,converting into ANSI 

    format as it copies.

  

  

   s: A managed string to be copied.

   Returns: The address,in unmanaged memory,to where s was copied,or 0 if s is null.
  """
  pass
 @staticmethod
 def StringToHGlobalAuto(s):
  """
  StringToHGlobalAuto(s: str) -> IntPtr

  

   Copies the contents of a managed System.String into unmanaged memory,converting into ANSI 

    format if required.

  

  

   s: A managed string to be copied.

   Returns: The address,in unmanaged memory,to where the string was copied,or 0 if s is null.
  """
  pass
 @staticmethod
 def StringToHGlobalUni(s):
  """
  StringToHGlobalUni(s: str) -> IntPtr

  

   Copies the contents of a managed System.String into unmanaged memory.

  

   s: A managed string to be copied.

   Returns: The address,in unmanaged memory,to where the s was copied,or 0 if s is null.
  """
  pass
 @staticmethod
 def StructureToPtr(structure,ptr,fDeleteOld):
  """
  StructureToPtr[T](structure: T,ptr: IntPtr,fDeleteOld: bool)StructureToPtr(structure: object,ptr: IntPtr,fDeleteOld: bool)

   Marshals data from a managed object to an unmanaged block of memory.

  

   structure: A managed object holding the data to be marshaled. This object must be an instance of a 

    formatted class.

  

   ptr: A pointer to an unmanaged block of memory,which must be allocated before this method is called.

   fDeleteOld: true to have the 

    System.Runtime.InteropServices.Marshal.DestroyStructure(System.IntPtr,System.Type) method called 

    on the ptr parameter before this method executes. Note that passing false can lead to a memory 

    leak.
  """
  pass
 @staticmethod
 def ThrowExceptionForHR(errorCode,errorInfo=None):
  """
  ThrowExceptionForHR(errorCode: int,errorInfo: IntPtr)

   Throws an exception with a specific failure HRESULT,based on the specified IErrorInfo Interface 

    interface.

  

  

   errorCode: The HRESULT corresponding to the desired exception.

   errorInfo: A pointer to the IErrorInfo interface that provides more information about the error. You can 

    specify IntPtr(0) to use the current IErrorInfo interface,or IntPtr(-1) to ignore the current 

    IErrorInfo interface and construct the exception just from the error code.

  

  ThrowExceptionForHR(errorCode: int)

   Throws an exception with a specific failure HRESULT value.

  

   errorCode: The HRESULT corresponding to the desired exception.
  """
  pass
 @staticmethod
 def UnsafeAddrOfPinnedArrayElement(arr,index):
  """
  UnsafeAddrOfPinnedArrayElement[T](arr: Array[T],index: int) -> IntPtr

  UnsafeAddrOfPinnedArrayElement(arr: Array,index: int) -> IntPtr

  

   Gets the address of the element at the specified index inside the specified array.

  

   arr: The array that contains the desired element.

   index: The index in the arr parameter of the desired element.

   Returns: The address of index inside arr.
  """
  pass
 @staticmethod
 def WriteByte(ptr,*__args):
  """
  WriteByte(ptr: IntPtr,val: Byte)

   Writes a single byte value to unmanaged memory.

  

   ptr: The address in unmanaged memory to write to.

   val: The value to write.

  WriteByte(ofs: int,val: Byte) -> object

  

   Writes a single byte value to unmanaged memory at a specified offset.

  

   ofs: An additional byte offset,which is added to the ptr parameter before writing.

   val: The value to write.

  WriteByte(ptr: IntPtr,ofs: int,val: Byte)

   Writes a single byte value to unmanaged memory at a specified offset.

  

   ptr: The base address in unmanaged memory to write to.

   ofs: An additional byte offset,which is added to the ptr parameter before writing.

   val: The value to write.
  """
  pass
 @staticmethod
 def WriteInt16(ptr,*__args):
  """
  WriteInt16(ptr: IntPtr,ofs: int,val: Char)

   Writes a 16-bit signed integer value to unmanaged memory at a specified offset.

  

   ptr: The base address in the native heap to write to.

   ofs: An additional byte offset,which is added to the ptr parameter before writing.

   val: The value to write.

  WriteInt16(ofs: int,val: Char) -> object

  

   Writes a 16-bit signed integer value to unmanaged memory at a specified offset.

  

   ofs: An additional byte offset,which is added to the ptr parameter before writing.

   val: The value to write.

  WriteInt16(ptr: IntPtr,val: Char)

   Writes a character as a 16-bit integer value to unmanaged memory.

  

   ptr: The address in unmanaged memory to write to.

   val: The value to write.

  WriteInt16(ptr: IntPtr,ofs: int,val: Int16)

   Writes a 16-bit signed integer value into unmanaged memory at a specified offset.

  

   ptr: The base address in unmanaged memory to write to.

   ofs: An additional byte offset,which is added to the ptr parameter before writing.

   val: The value to write.

  WriteInt16(ofs: int,val: Int16) -> object

  

   Writes a 16-bit signed integer value to unmanaged memory at a specified offset.

  

   ofs: An additional byte offset,which is added to the ptr parameter before writing.

   val: The value to write.

  WriteInt16(ptr: IntPtr,val: Int16)

   Writes a 16-bit integer value to unmanaged memory.

  

   ptr: The address in unmanaged memory to write to.

   val: The value to write.
  """
  pass
 @staticmethod
 def WriteInt32(ptr,*__args):
  """
  WriteInt32(ptr: IntPtr,val: int)

   Writes a 32-bit signed integer value to unmanaged memory.

  

   ptr: The address in unmanaged memory to write to.

   val: The value to write.

  WriteInt32(ofs: int,val: int) -> object

  

   Writes a 32-bit signed integer value to unmanaged memory at a specified offset.

  

   ofs: An additional byte offset,which is added to the ptr parameter before writing.

   val: The value to write.

  WriteInt32(ptr: IntPtr,ofs: int,val: int)

   Writes a 32-bit signed integer value into unmanaged memory at a specified offset.

  

   ptr: The base address in unmanaged memory to write to.

   ofs: An additional byte offset,which is added to the ptr parameter before writing.

   val: The value to write.
  """
  pass
 @staticmethod
 def WriteInt64(ptr,*__args):
  """
  WriteInt64(ptr: IntPtr,val: Int64)

   Writes a 64-bit signed integer value to unmanaged memory.

  

   ptr: The address in unmanaged memory to write to.

   val: The value to write.

  WriteInt64(ofs: int,val: Int64) -> object

  

   Writes a 64-bit signed integer value to unmanaged memory at a specified offset.

  

   ofs: An additional byte offset,which is added to the ptr parameter before writing.

   val: The value to write.

  WriteInt64(ptr: IntPtr,ofs: int,val: Int64)

   Writes a 64-bit signed integer value to unmanaged memory at a specified offset.

  

   ptr: The base address in unmanaged memory to write.

   ofs: An additional byte offset,which is added to the ptr parameter before writing.

   val: The value to write.
  """
  pass
 @staticmethod
 def WriteIntPtr(ptr,*__args):
  """
  WriteIntPtr(ptr: IntPtr,val: IntPtr)

   Writes a processor native sized integer value into unmanaged memory.

  

   ptr: The address in unmanaged memory to write to.

   val: The value to write.

  WriteIntPtr(ofs: int,val: IntPtr) -> object

  

   Writes a processor native sized integer value to unmanaged memory.

  

   ofs: An additional byte offset,which is added to the ptr parameter before writing.

   val: The value to write.

  WriteIntPtr(ptr: IntPtr,ofs: int,val: IntPtr)

   Writes a processor native-sized integer value to unmanaged memory at a specified offset.

  

   ptr: The base address in unmanaged memory to write to.

   ofs: An additional byte offset,which is added to the ptr parameter before writing.

   val: The value to write.
  """
  pass
 @staticmethod
 def ZeroFreeBSTR(s):
  """
  ZeroFreeBSTR(s: IntPtr)

   Frees a BSTR Data Type pointer that was allocated using the 

    System.Runtime.InteropServices.Marshal.SecureStringToBSTR(System.Security.SecureString) method.

  

  

   s: The address of the BSTR to free.
  """
  pass
 @staticmethod
 def ZeroFreeCoTaskMemAnsi(s):
  """
  ZeroFreeCoTaskMemAnsi(s: IntPtr)

   Frees an unmanaged string pointer that was allocated using the 

    System.Runtime.InteropServices.Marshal.SecureStringToCoTaskMemAnsi(System.Security.SecureString) 

    method.

  

  

   s: The address of the unmanaged string to free.
  """
  pass
 @staticmethod
 def ZeroFreeCoTaskMemUnicode(s):
  """
  ZeroFreeCoTaskMemUnicode(s: IntPtr)

   Frees an unmanaged string pointer that was allocated using the 

    System.Runtime.InteropServices.Marshal.SecureStringToCoTaskMemUnicode(System.Security.SecureStrin

    g) method.

  

  

   s: The address of the unmanaged string to free.
  """
  pass
 @staticmethod
 def ZeroFreeGlobalAllocAnsi(s):
  """
  ZeroFreeGlobalAllocAnsi(s: IntPtr)

   Frees an unmanaged string pointer that was allocated using the 

    System.Runtime.InteropServices.Marshal.SecureStringToGlobalAllocAnsi(System.Security.SecureString

    ) method.

  

  

   s: The address of the unmanaged string to free.
  """
  pass
 @staticmethod
 def ZeroFreeGlobalAllocUnicode(s):
  """
  ZeroFreeGlobalAllocUnicode(s: IntPtr)

   Frees an unmanaged string pointer that was allocated using the 

    System.Runtime.InteropServices.Marshal.SecureStringToGlobalAllocUnicode(System.Security.SecureStr

    ing) method.

  

  

   s: The address of the unmanaged string to free.
  """
  pass
 SystemDefaultCharSize=2
 SystemMaxDBCSCharSize=1
 __all__=[
  'AddRef',
  'AllocCoTaskMem',
  'AllocHGlobal',
  'AreComObjectsAvailableForCleanup',
  'BindToMoniker',
  'ChangeWrapperHandleStrength',
  'CleanupUnusedObjectsInCurrentContext',
  'Copy',
  'CreateAggregatedObject',
  'CreateWrapperOfType',
  'DestroyStructure',
  'FinalReleaseComObject',
  'FreeBSTR',
  'FreeCoTaskMem',
  'FreeHGlobal',
  'GenerateGuidForType',
  'GenerateProgIdForType',
  'GetActiveObject',
  'GetComInterfaceForObject',
  'GetComInterfaceForObjectInContext',
  'GetComObjectData',
  'GetComSlotForMethodInfo',
  'GetDelegateForFunctionPointer',
  'GetEndComSlot',
  'GetExceptionCode',
  'GetExceptionForHR',
  'GetExceptionPointers',
  'GetFunctionPointerForDelegate',
  'GetHINSTANCE',
  'GetHRForException',
  'GetHRForLastWin32Error',
  'GetIDispatchForObject',
  'GetIDispatchForObjectInContext',
  'GetITypeInfoForType',
  'GetIUnknownForObject',
  'GetIUnknownForObjectInContext',
  'GetLastWin32Error',
  'GetManagedThunkForUnmanagedMethodPtr',
  'GetMethodInfoForComSlot',
  'GetNativeVariantForObject',
  'GetObjectForIUnknown',
  'GetObjectForNativeVariant',
  'GetObjectsForNativeVariants',
  'GetStartComSlot',
  'GetThreadFromFiberCookie',
  'GetTypedObjectForIUnknown',
  'GetTypeForITypeInfo',
  'GetTypeFromCLSID',
  'GetTypeInfoName',
  'GetTypeLibGuid',
  'GetTypeLibGuidForAssembly',
  'GetTypeLibLcid',
  'GetTypeLibName',
  'GetTypeLibVersionForAssembly',
  'GetUniqueObjectForIUnknown',
  'GetUnmanagedThunkForManagedMethodPtr',
  'IsComObject',
  'IsTypeVisibleFromCom',
  'NumParamBytes',
  'OffsetOf',
  'Prelink',
  'PrelinkAll',
  'PtrToStringAnsi',
  'PtrToStringAuto',
  'PtrToStringBSTR',
  'PtrToStringUni',
  'PtrToStructure',
  'QueryInterface',
  'ReadByte',
  'ReadInt16',
  'ReadInt32',
  'ReadInt64',
  'ReadIntPtr',
  'ReAllocCoTaskMem',
  'ReAllocHGlobal',
  'Release',
  'ReleaseComObject',
  'ReleaseThreadCache',
  'SecureStringToBSTR',
  'SecureStringToCoTaskMemAnsi',
  'SecureStringToCoTaskMemUnicode',
  'SecureStringToGlobalAllocAnsi',
  'SecureStringToGlobalAllocUnicode',
  'SetComObjectData',
  'SizeOf',
  'StringToBSTR',
  'StringToCoTaskMemAnsi',
  'StringToCoTaskMemAuto',
  'StringToCoTaskMemUni',
  'StringToHGlobalAnsi',
  'StringToHGlobalAuto',
  'StringToHGlobalUni',
  'StructureToPtr',
  'SystemDefaultCharSize',
  'SystemMaxDBCSCharSize',
  'ThrowExceptionForHR',
  'UnsafeAddrOfPinnedArrayElement',
  'WriteByte',
  'WriteInt16',
  'WriteInt32',
  'WriteInt64',
  'WriteIntPtr',
  'ZeroFreeBSTR',
  'ZeroFreeCoTaskMemAnsi',
  'ZeroFreeCoTaskMemUnicode',
  'ZeroFreeGlobalAllocAnsi',
  'ZeroFreeGlobalAllocUnicode',
 ]




class DataGridRowDetailsEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Controls.DataGrid.LoadingRowDetails,System.Windows.Controls.DataGrid.UnloadingRowDetails,and System.Windows.Controls.DataGrid.RowDetailsVisibilityChanged events.

 

 DataGridRowDetailsEventArgs(row: DataGridRow,detailsElement: FrameworkElement)
 """
 @staticmethod
 def __new__(self,row,detailsElement):
  """ __new__(cls: type,row: DataGridRow,detailsElement: FrameworkElement) """
  pass
 DetailsElement=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the row details section as a framework element.



Get: DetailsElement(self: DataGridRowDetailsEventArgs) -> FrameworkElement



"""

 Row=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the row for which the event occurred.



Get: Row(self: DataGridRowDetailsEventArgs) -> DataGridRow



"""





class DesignTimeVisibleAttribute(Attribute,_Attribute):
 """
 System.ComponentModel.DesignTimeVisibleAttribute marks a component's visibility. If System.ComponentModel.DesignTimeVisibleAttribute.Yes is present,a visual designer can show this component on a designer.

 

 DesignTimeVisibleAttribute(visible: bool)

 DesignTimeVisibleAttribute()
 """
 def Equals(self,obj):
  """
  Equals(self: DesignTimeVisibleAttribute,obj: object) -> bool

  

   obj: The object to compare.
  """
  pass
 def GetHashCode(self):
  """ GetHashCode(self: DesignTimeVisibleAttribute) -> int """
  pass
 def IsDefaultAttribute(self):
  """
  IsDefaultAttribute(self: DesignTimeVisibleAttribute) -> bool

  

   Gets a value indicating if this instance is equal to the 

    System.ComponentModel.DesignTimeVisibleAttribute.Default value.

  

   Returns: true,if this instance is equal to the System.ComponentModel.DesignTimeVisibleAttribute.Default 

    value; otherwise,false.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,visible=None):
  """
  __new__(cls: type,visible: bool)

  __new__(cls: type)
  """
  pass
 def __ne__(self,*args):
  pass
 Visible=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets whether the component should be shown at design time.



Get: Visible(self: DesignTimeVisibleAttribute) -> bool



"""


 Default=None
 No=None
 Yes=None




class ListViewGroup(object,ISerializable):
 """
 Represents a group of items displayed within a System.Windows.Forms.ListView control.

 

 ListViewGroup()

 ListViewGroup(key: str,headerText: str)

 ListViewGroup(header: str)

 ListViewGroup(header: str,headerAlignment: HorizontalAlignment)
 """
 def ToString(self):
  """
  ToString(self: ListViewGroup) -> str

   Returns: A string that represents the current object.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,key: str,headerText: str)

  __new__(cls: type,header: str)

  __new__(cls: type,header: str,headerAlignment: HorizontalAlignment)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __str__(self,*args):
  pass
 Header=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the header text for the group.



Get: Header(self: ListViewGroup) -> str



Set: Header(self: ListViewGroup)=value

"""

 HeaderAlignment=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the alignment of the group header text.



Get: HeaderAlignment(self: ListViewGroup) -> HorizontalAlignment



Set: HeaderAlignment(self: ListViewGroup)=value

"""

 Items=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection containing all items associated with this group.



Get: Items(self: ListViewGroup) -> ListViewItemCollection



"""

 ListView=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Forms.ListView control that contains this group.



Get: ListView(self: ListViewGroup) -> ListView



"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the group.



Get: Name(self: ListViewGroup) -> str



Set: Name(self: ListViewGroup)=value

"""

 Tag=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the object that contains data about the group.



Get: Tag(self: ListViewGroup) -> object



Set: Tag(self: ListViewGroup)=value

"""





class DataGridViewCellParsingEventArgs(ConvertEventArgs):
 """
 Provides data for the System.Windows.Forms.DataGridView.CellParsing event of a System.Windows.Forms.DataGridView control.

 

 DataGridViewCellParsingEventArgs(rowIndex: int,columnIndex: int,value: object,desiredType: Type,inheritedCellStyle: DataGridViewCellStyle)
 """
 @staticmethod
 def __new__(self,rowIndex,columnIndex,value,desiredType,inheritedCellStyle):
  """ __new__(cls: type,rowIndex: int,columnIndex: int,value: object,desiredType: Type,inheritedCellStyle: DataGridViewCellStyle) """
  pass
 ColumnIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the column index of the cell data that requires parsing.



Get: ColumnIndex(self: DataGridViewCellParsingEventArgs) -> int



"""

 InheritedCellStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the style applied to the edited cell.



Get: InheritedCellStyle(self: DataGridViewCellParsingEventArgs) -> DataGridViewCellStyle



Set: InheritedCellStyle(self: DataGridViewCellParsingEventArgs)=value

"""

 ParsingApplied=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether a cell's value has been successfully parsed.



Get: ParsingApplied(self: DataGridViewCellParsingEventArgs) -> bool



Set: ParsingApplied(self: DataGridViewCellParsingEventArgs)=value

"""

 RowIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the row index of the cell that requires parsing.



Get: RowIndex(self: DataGridViewCellParsingEventArgs) -> int



"""





class EventLogPermissionAttribute(CodeAccessSecurityAttribute,_Attribute):
 """
 Allows declaritive permission checks for event logging.

 

 EventLogPermissionAttribute(action: SecurityAction)
 """
 def CreatePermission(self):
  """
  CreatePermission(self: EventLogPermissionAttribute) -> IPermission

  

   Creates the permission based on the System.Diagnostics.EventLogPermissionAttribute.MachineName 

    property and the requested access levels that are set through the 

    System.Diagnostics.EventLogPermissionAttribute.PermissionAccess property on the attribute.

  

   Returns: An System.Security.IPermission that represents the created permission.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,action):
  """ __new__(cls: type,action: SecurityAction) """
  pass
 def __reduce_ex__(self,*args):
  pass
 MachineName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the computer on which events might be read.



Get: MachineName(self: EventLogPermissionAttribute) -> str



Set: MachineName(self: EventLogPermissionAttribute)=value

"""

 PermissionAccess=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the access levels used in the permissions request.



Get: PermissionAccess(self: EventLogPermissionAttribute) -> EventLogPermissionAccess



Set: PermissionAccess(self: EventLogPermissionAttribute)=value

"""





"""Base module for handling extensions parsing."""

# Extension types
# ------------------------------------------------------------------------------
LIB_EXTENSION_POSTFIX = '.lib'
UI_EXTENSION_POSTFIX = '.extension'


class UIExtensionType:
    """UI extension type."""
    ID = 'extension'
    POSTFIX = '.extension'


class LIBExtensionType:
    """Library extension type."""
    ID = 'lib'
    POSTFIX = '.lib'


class ExtensionTypes:
    """Extension types."""
    UI_EXTENSION = UIExtensionType
    LIB_EXTENSION = LIBExtensionType

    @classmethod
    def get_ext_types(cls):
        ext_types = set()
        for attr in dir(cls):
            if attr.endswith('_EXTENSION'):
                ext_types.add(getattr(cls, attr))
        return ext_types


# -----------------------------------------------------------------------------
# supported scripting languages
PYTHON_LANG = 'python'
CSHARP_LANG = 'csharp'
VB_LANG = 'visualbasic'
RUBY_LANG = 'ruby'
DYNAMO_LANG = 'dynamobim'
GRASSHOPPER_LANG = 'grasshopper'
# cpython hash-bang
CPYTHON_HASHBANG = '#! python3'

# supported script files
PYTHON_SCRIPT_FILE_FORMAT = '.py'
CSHARP_SCRIPT_FILE_FORMAT = '.cs'
VB_SCRIPT_FILE_FORMAT = '.vb'
RUBY_SCRIPT_FILE_FORMAT = '.rb'
DYNAMO_SCRIPT_FILE_FORMAT = '.dyn'
GRASSHOPPER_SCRIPT_FILE_FORMAT = '.gh'
GRASSHOPPERX_SCRIPT_FILE_FORMAT = '.ghx'
CONTENT_FILE_FORMAT = '.rfa'

# extension startup script
EXT_STARTUP_NAME = 'startup'
PYTHON_EXT_STARTUP_FILE = EXT_STARTUP_NAME + PYTHON_SCRIPT_FILE_FORMAT
CSHARP_EXT_STARTUP_FILE = EXT_STARTUP_NAME + CSHARP_SCRIPT_FILE_FORMAT
VB_EXT_STARTUP_FILE = EXT_STARTUP_NAME + VB_SCRIPT_FILE_FORMAT
RUBY_EXT_STARTUP_FILE = EXT_STARTUP_NAME + RUBY_SCRIPT_FILE_FORMAT

# -----------------------------------------------------------------------------
# supported metadata formats
YAML_FILE_FORMAT = '.yaml'
JSON_FILE_FORMAT = '.json'

# metadata filenames
EXT_MANIFEST_NAME = 'extension'
EXT_MANIFEST_FILE = EXT_MANIFEST_NAME + JSON_FILE_FORMAT

DEFAULT_BUNDLEMATA_NAME = 'bundle'
BUNDLEMATA_POSTFIX = DEFAULT_BUNDLEMATA_NAME + YAML_FILE_FORMAT

# metadata schema: Exensions

# metadata schema: Bundles
MDATA_UI_TITLE = 'title'
MDATA_TOOLTIP = 'tooltip'
MDATA_AUTHOR = 'author'
MDATA_AUTHORS = 'authors'
MDATA_LAYOUT = 'layout'
MDATA_CONTENT = 'content'
MDATA_CONTENT_ALT = 'content_alt'
MDATA_COMMAND_HELP_URL = 'help_url'
MDATA_COMMAND_CONTEXT = 'context'
MDATA_COMMAND_CONTEXT_TYPE = "type"
MDATA_COMMAND_CONTEXT_NOT = "not_"
MDATA_COMMAND_CONTEXT_ANY = "any"
MDATA_COMMAND_CONTEXT_ALL = "all"
MDATA_COMMAND_CONTEXT_EXACT = "exact"
MDATA_COMMAND_CONTEXT_NOTANY = (MDATA_COMMAND_CONTEXT_NOT +
                                MDATA_COMMAND_CONTEXT_ANY)
MDATA_COMMAND_CONTEXT_NOTALL = (MDATA_COMMAND_CONTEXT_NOT +
                                MDATA_COMMAND_CONTEXT_ALL)
MDATA_COMMAND_CONTEXT_NOTEXACT = (MDATA_COMMAND_CONTEXT_NOT +
                                  MDATA_COMMAND_CONTEXT_EXACT)
MDATA_COMMAND_CONTEXT_ANY_SEP = "|"
MDATA_COMMAND_CONTEXT_ALL_SEP = "&"
MDATA_COMMAND_CONTEXT_EXACT_SEP = ";"
MDATA_COMMAND_CONTEXT_RULE = "({rule})"
MDATA_MIN_REVIT_VERSION = 'min_revit_version'
MDATA_MAX_REVIT_VERSION = 'max_revit_version'
MDATA_BETA_SCRIPT = 'is_beta'
MDATA_ENGINE = 'engine'
MDATA_ENGINE_CLEAN = 'clean'
MDATA_ENGINE_FULLFRAME = 'full_frame'
MDATA_ENGINE_PERSISTENT = 'persistent'
MDATA_ENGINE_MAINTHREAD = 'mainthread'
MDATA_LINK_BUTTON_MODULES = 'modules'
MDATA_LINK_BUTTON_ASSEMBLY = 'assembly'
MDATA_LINK_BUTTON_COMMAND_CLASS = 'command_class'
MDATA_LINK_BUTTON_AVAIL_COMMAND_CLASS = 'availability_class'
MDATA_URL_BUTTON_HYPERLINK = 'hyperlink'
MDATA_TEMPLATES_KEY = 'templates'
MDATA_BACKGROUND_KEY = 'background'
MDATA_BACKGROUND_PANEL_KEY = 'panel'
MDATA_BACKGROUND_TITLE_KEY = 'title'
MDATA_BACKGROUND_SLIDEOUT_KEY = 'slideout'
MDATA_HIGHLIGHT_KEY = 'highlight'
MDATA_HIGHLIGHT_TYPE_NEW = 'new'
MDATA_HIGHLIGHT_TYPE_UPDATED = 'updated'
MDATA_COLLAPSED_KEY = 'collapsed'
# metadata schema: DynamoBIM bundles
MDATA_ENGINE_DYNAMO_AUTOMATE = 'automate'
MDATA_ENGINE_DYNAMO_PATH = 'dynamo_path'
# MDATA_ENGINE_DYNAMO_PATH_EXEC = 'dynamo_path_exec'
MDATA_ENGINE_DYNAMO_PATH_CHECK_EXIST = 'dynamo_path_check_existing'
MDATA_ENGINE_DYNAMO_FORCE_MANUAL_RUN = 'dynamo_force_manual_run'
MDATA_ENGINE_DYNAMO_MODEL_NODES_INFO = 'dynamo_model_nodes_info'

# metadata schema: Bundles | legacy
UI_TITLE_PARAM = '__title__'
DOCSTRING_PARAM = '__doc__'
AUTHOR_PARAM = '__author__'
AUTHORS_PARAM = '__authors__'
COMMAND_HELP_URL_PARAM = '__helpurl__'
COMMAND_CONTEXT_PARAM = '__context__'
MIN_REVIT_VERSION_PARAM = '__min_revit_ver__'
MAX_REVIT_VERSION_PARAM = '__max_revit_ver__'
SHIFT_CLICK_PARAM = '__shiftclick__'
BETA_SCRIPT_PARAM = '__beta__'
HIGHLIGHT_SCRIPT_PARAM = '__highlight__'
CLEAN_ENGINE_SCRIPT_PARAM = '__cleanengine__'
FULLFRAME_ENGINE_PARAM = '__fullframeengine__'
PERSISTENT_ENGINE_PARAM = '__persistentengine__'

# -----------------------------------------------------------------------------
# supported bundles
TAB_POSTFIX = '.tab'
PANEL_POSTFIX = '.panel'
LINK_BUTTON_POSTFIX = '.linkbutton'
INVOKE_BUTTON_POSTFIX = '.invokebutton'
PUSH_BUTTON_POSTFIX = '.pushbutton'
SMART_BUTTON_POSTFIX = '.smartbutton'
PULLDOWN_BUTTON_POSTFIX = '.pulldown'
STACK_BUTTON_POSTFIX = '.stack'
SPLIT_BUTTON_POSTFIX = '.splitbutton'
SPLITPUSH_BUTTON_POSTFIX = '.splitpushbutton'
PANEL_PUSH_BUTTON_POSTFIX = '.panelbutton'
NOGUI_COMMAND_POSTFIX = '.nobutton'
CONTENT_BUTTON_POSTFIX = '.content'
URL_BUTTON_POSTFIX = '.urlbutton'

# known bundle sub-directories
COMP_LIBRARY_DIR_NAME = 'lib'
COMP_BIN_DIR_NAME = 'bin'
COMP_HOOKS_DIR_NAME = 'hooks'
COMP_CHECKS_DIR_NAME = 'checks'

# unique ids
UNIQUE_ID_SEPARATOR = '-'

# bundle layout elements
SEPARATOR_IDENTIFIER = '---'
SLIDEOUT_IDENTIFIER = '>>>'

# bundle icon
ICON_FILE_FORMAT = '.png'
ICON_DARK_SUFFIX = '.dark'
DEFAULT_ICON_FILE = 'icon' + ICON_FILE_FORMAT
DEFAULT_ON_ICON_FILE = 'on' + ICON_FILE_FORMAT
DEFAULT_OFF_ICON_FILE = 'off' + ICON_FILE_FORMAT

# bundle media for tooltips
DEFAULT_MEDIA_FILENAME = 'tooltip'

# bundle scripts
DEFAULT_SCRIPT_NAME = 'script'
DEFAULT_CONFIG_NAME = 'config'

# script files
PYTHON_SCRIPT_POSTFIX = DEFAULT_SCRIPT_NAME + PYTHON_SCRIPT_FILE_FORMAT
PYTHON_CONFIG_SCRIPT_POSTFIX = DEFAULT_CONFIG_NAME + PYTHON_SCRIPT_FILE_FORMAT

CSHARP_SCRIPT_POSTFIX = DEFAULT_SCRIPT_NAME + CSHARP_SCRIPT_FILE_FORMAT
CSHARP_CONFIG_SCRIPT_POSTFIX = DEFAULT_CONFIG_NAME + CSHARP_SCRIPT_FILE_FORMAT

VB_SCRIPT_POSTFIX = DEFAULT_SCRIPT_NAME + VB_SCRIPT_FILE_FORMAT
VB_CONFIG_SCRIPT_POSTFIX = DEFAULT_CONFIG_NAME + VB_SCRIPT_FILE_FORMAT

RUBY_SCRIPT_POSTFIX = DEFAULT_SCRIPT_NAME + RUBY_SCRIPT_FILE_FORMAT
RUBY_CONFIG_SCRIPT_POSTFIX = DEFAULT_CONFIG_NAME + RUBY_SCRIPT_FILE_FORMAT

DYNAMO_SCRIPT_POSTFIX = DEFAULT_SCRIPT_NAME + DYNAMO_SCRIPT_FILE_FORMAT
DYNAMO_CONFIG_SCRIPT_POSTFIX = DEFAULT_CONFIG_NAME + DYNAMO_SCRIPT_FILE_FORMAT

GRASSHOPPER_SCRIPT_POSTFIX = \
    DEFAULT_SCRIPT_NAME + GRASSHOPPER_SCRIPT_FILE_FORMAT
GRASSHOPPER_CONFIG_SCRIPT_POSTFIX = \
    DEFAULT_CONFIG_NAME + GRASSHOPPER_SCRIPT_FILE_FORMAT

GRASSHOPPERX_SCRIPT_POSTFIX = \
    DEFAULT_SCRIPT_NAME + GRASSHOPPERX_SCRIPT_FILE_FORMAT
GRASSHOPPERX_CONFIG_SCRIPT_POSTFIX = \
    DEFAULT_CONFIG_NAME + GRASSHOPPERX_SCRIPT_FILE_FORMAT

# bundle content
DEFAULT_CONTENT_NAME = 'content'
DEFAULT_ALT_CONTENT_NAME = 'other'

CONTENT_POSTFIX = DEFAULT_CONTENT_NAME + CONTENT_FILE_FORMAT
CONTENT_VERSION_POSTFIX = \
    DEFAULT_CONTENT_NAME + "_{version}" + CONTENT_FILE_FORMAT

ALT_CONTENT_POSTFIX = DEFAULT_ALT_CONTENT_NAME + CONTENT_FILE_FORMAT
ALT_CONTENT_VERSION_POSTFIX = \
    DEFAULT_ALT_CONTENT_NAME + "_{version}" + CONTENT_FILE_FORMAT

# bundle help
HELP_FILE_PATTERN = r'.*help\..+'

# -----------------------------------------------------------------------------
# Command bundle defaults
CTX_SELETION = 'selection'
CTX_ZERODOC = 'zero-doc'



class TableLayoutCellPaintEventArgs(PaintEventArgs,IDisposable):
 """
 Provides data for the System.Windows.Forms.TableLayoutPanel.CellPaint event.

 

 TableLayoutCellPaintEventArgs(g: Graphics,clipRectangle: Rectangle,cellBounds: Rectangle,column: int,row: int)
 """
 def Dispose(self):
  """
  Dispose(self: PaintEventArgs,disposing: bool)

   Releases the unmanaged resources used by the System.Windows.Forms.PaintEventArgs and optionally 

    releases the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,g,clipRectangle,cellBounds,column,row):
  """ __new__(cls: type,g: Graphics,clipRectangle: Rectangle,cellBounds: Rectangle,column: int,row: int) """
  pass
 CellBounds=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the size and location of the cell.



Get: CellBounds(self: TableLayoutCellPaintEventArgs) -> Rectangle



"""

 Column=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the column of the cell.



Get: Column(self: TableLayoutCellPaintEventArgs) -> int



"""

 Row=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the row of the cell.



Get: Row(self: TableLayoutCellPaintEventArgs) -> int



"""





class Environment(object):
 """ Provides information about,and means to manipulate,the current environment and platform. This class cannot be inherited. """
 @staticmethod
 def Exit(exitCode):
  """
  Exit(exitCode: int)

   Terminates this process and gives the underlying operating system the specified exit code.

  

   exitCode: Exit code to be given to the operating system.
  """
  pass
 @staticmethod
 def ExpandEnvironmentVariables(name):
  """
  ExpandEnvironmentVariables(name: str) -> str

  

   Replaces the name of each environment variable embedded in the specified string with the string 

    equivalent of the value of the variable,then returns the resulting string.

  

  

   name: A string containing the names of zero or more environment variables. Each environment variable 

    is quoted with the percent sign character (%).

  

   Returns: A string with each environment variable replaced by its value.
  """
  pass
 @staticmethod
 def FailFast(message,exception=None):
  """
  FailFast(message: str,exception: Exception)

   Immediately terminates a process after writing a message to the Windows Application event log,

    and then includes the message and exception information in error reporting to Microsoft.

  

  

   message: A message that explains why the process was terminated,or null if no explanation is provided.

   exception: An exception that represents the error that caused the termination. This is typically the 

    exception in a catch block.

  

  FailFast(message: str)

   Immediately terminates a process after writing a message to the Windows Application event log,

    and then includes the message in error reporting to Microsoft.

  

  

   message: A message that explains why the process was terminated,or null if no explanation is provided.
  """
  pass
 @staticmethod
 def GetCommandLineArgs():
  """
  GetCommandLineArgs() -> Array[str]

  

   Returns a string array containing the command-line arguments for the current process.

   Returns: An array of string where each element contains a command-line argument. The first element is the 

    executable file name,and the following zero or more elements contain the remaining command-line 

    arguments.
  """
  pass
 @staticmethod
 def GetEnvironmentVariable(variable,target=None):
  """
  GetEnvironmentVariable(variable: str,target: EnvironmentVariableTarget) -> str

  

   Retrieves the value of an environment variable from the current process or from the Windows 

    operating system registry key for the current user or local machine.

  

  

   variable: The name of an environment variable.

   target: One of the System.EnvironmentVariableTarget values.

   Returns: The value of the environment variable specified by the variable and target parameters,or null 

    if the environment variable is not found.

  

  GetEnvironmentVariable(variable: str) -> str

  

   Retrieves the value of an environment variable from the current process.

  

   variable: The name of the environment variable.

   Returns: The value of the environment variable specified by variable,or null if the environment variable 

    is not found.
  """
  pass
 @staticmethod
 def GetEnvironmentVariables(target=None):
  """
  GetEnvironmentVariables(target: EnvironmentVariableTarget) -> IDictionary

  

   Retrieves all environment variable names and their values from the current process,or from the 

    Windows operating system registry key for the current user or local machine.

  

  

   target: One of the System.EnvironmentVariableTarget values.

   Returns: A dictionary that contains all environment variable names and their values from the source 

    specified by the target parameter; otherwise,an empty dictionary if no environment variables 

    are found.

  

  GetEnvironmentVariables() -> IDictionary

  

   Retrieves all environment variable names and their values from the current process.

   Returns: A dictionary that contains all environment variable names and their values; otherwise,an empty 

    dictionary if no environment variables are found.
  """
  pass
 @staticmethod
 def GetFolderPath(folder,option=None):
  """
  GetFolderPath(folder: SpecialFolder,option: SpecialFolderOption) -> str

  GetFolderPath(folder: SpecialFolder) -> str
  """
  pass
 @staticmethod
 def GetLogicalDrives():
  """
  GetLogicalDrives() -> Array[str]

  

   Returns an array of string containing the names of the logical drives on the current computer.

   Returns: An array of strings where each element contains the name of a logical drive. For example,if the 

    computer's hard drive is the first logical drive,the first element returned is "C:\".
  """
  pass
 @staticmethod
 def SetEnvironmentVariable(variable,value,target=None):
  """
  SetEnvironmentVariable(variable: str,value: str,target: EnvironmentVariableTarget)

   Creates,modifies,or deletes an environment variable stored in the current process or in the 

    Windows operating system registry key reserved for the current user or local machine.

  

  

   variable: The name of an environment variable.

   value: A value to assign to variable.

   target: One of the System.EnvironmentVariableTarget values.

  SetEnvironmentVariable(variable: str,value: str)

   Creates,modifies,or deletes an environment variable stored in the current process.

  

   variable: The name of an environment variable.

   value: A value to assign to variable.
  """
  pass
 CommandLine='ipy  -m ironstubs make System --folder=stubs2 --overwrite'
 CurrentDirectory='D:\\Dropbox\\Shared\\dev\\repos\\ironpython-stubs'
 CurrentManagedThreadId=1
 ExitCode=0
 HasShutdownStarted=False
 Is64BitOperatingSystem=True
 Is64BitProcess=False
 MachineName='STUDIO-SSD'
 NewLine='\r\n'
 OSVersion=None
 ProcessorCount=8
 SpecialFolder=None
 SpecialFolderOption=None
 StackTrace='   at System.Environment.GetStackTrace(Exception e,Boolean needFileInfo)\r\n   at System.Environment.get_StackTrace()\r\n   at Microsoft.Scripting.Interpreter.FuncCallInstruction`1.Run(InterpretedFrame frame)\r\n   at Microsoft.Scripting.Interpreter.Interpreter.Run(InterpretedFrame frame)\r\n   at Microsoft.Scripting.Interpreter.LightLambda.Run3[T0,T1,T2,TRet](T0 arg0,T1 arg1,T2 arg2)\r\n   at System.Dynamic.UpdateDelegates.UpdateAndExecute2[T0,T1,TRet](CallSite site,T0 arg0,T1 arg1)\r\n   at Microsoft.Scripting.Interpreter.FuncCallInstruction`5.Run(InterpretedFrame frame)\r\n   at Microsoft.Scripting.Interpreter.Interpreter.Run(InterpretedFrame frame)\r\n   at Microsoft.Scripting.Interpreter.LightLambda.Run3[T0,T1,T2,TRet](T0 arg0,T1 arg1,T2 arg2)\r\n   at IronPython.Runtime.Types.BuiltinFunction.Call0(CodeContext context,SiteLocalStorage`1 storage,Object instance)\r\n   at IronPython.Runtime.Types.ReflectedProperty.CallGetter(CodeContext context,PythonType owner,SiteLocalStorage`1 storage,Object instance)\r\n   at IronPython.Runtime.Types.ReflectedProperty.TryGetValue(CodeContext context,Object instance,PythonType owner,Object& value)\r\n   at IronPython.Runtime.Binding.MetaPythonType.FastGetBinderHelper.SlotAccessDelegate.Target(CodeContext context,Object self,Object& result)\r\n   at IronPython.Runtime.Types.TypeGetBase.RunDelegates(Object self,CodeContext context)\r\n   at IronPython.Runtime.Types.SystemTypeGet.TargetOptimizing(CallSite site,Object self,CodeContext context)\r\n   at System.Dynamic.UpdateDelegates.UpdateAndExecute2[T0,T1,TRet](CallSite site,T0 arg0,T1 arg1)\r\n   at IronPython.Runtime.Binding.FastGetBase.Update(CallSite site,Object self,CodeContext context)\r\n   at IronPython.Runtime.Types.SystemTypeGet.TargetOptimizing(CallSite site,Object self,CodeContext context)\r\n   at IronPython.Runtime.Types.PythonType.TryGetBoundAttr(CodeContext context,Object o,String name,Object& ret)\r\n   at IronPython.Runtime.Operations.PythonOps.GetBoundAttr(CodeContext context,Object o,String name)\r\n   at IronPython.Modules.Builtin.getattr(CodeContext context,Object o,String name)\r\n   at redo_class$431(Closure ,PythonFunction ,Object ,Object ,Object ,Object ,Object ,Object ,Object ,Object )\r\n   at Microsoft.Scripting.Interpreter.LightLambda.Run9[T0,T1,T2,T3,T4,T5,T6,T7,T8,TRet](T0 arg0,T1 arg1,T2 arg2,T3 arg3,T4 arg4,T5 arg5,T6 arg6,T7 arg7,T8 arg8)\r\n   at CallSite.Target(Closure ,CallSite ,CodeContext ,Object ,Object ,Object ,Object ,Object ,Object ,Object ,Object )\r\n   at redo$418(Closure ,PythonFunction ,Object ,Object ,Object )\r\n   at Microsoft.Scripting.Interpreter.LightLambda.Run4[T0,T1,T2,T3,TRet](T0 arg0,T1 arg1,T2 arg2,T3 arg3)\r\n   at IronPython.Runtime.FunctionCaller`3.Call3(CallSite site,CodeContext context,Object func,T0 arg0,T1 arg1,T2 arg2)\r\n   at System.Dynamic.UpdateDelegates.UpdateAndExecute5[T0,T1,T2,T3,T4,TRet](CallSite site,T0 arg0,T1 arg1,T2 arg2,T3 arg3,T4 arg4)\r\n   at IronPython.Runtime.FunctionCaller`3.Call3(CallSite site,CodeContext context,Object func,T0 arg0,T1 arg1,T2 arg2)\r\n   at IronPython.Runtime.Method.MethodBinding`2.SelfTarget(CallSite site,CodeContext context,Object target,T0 arg0,T1 arg1)\r\n   at redo_module$415(Closure ,PythonFunction ,Object ,Object ,Object ,Object )\r\n   at Microsoft.Scripting.Interpreter.LightLambda.Run5[T0,T1,T2,T3,T4,TRet](T0 arg0,T1 arg1,T2 arg2,T3 arg3,T4 arg4)\r\n   at process_one$408(Closure ,PythonFunction ,Object ,Object ,Object ,Object ,Object )\r\n   at Microsoft.Scripting.Interpreter.LightLambda.Run6[T0,T1,T2,T3,T4,T5,TRet](T0 arg0,T1 arg1,T2 arg2,T3 arg3,T4 arg4,T5 arg5)\r\n   at create_stubs$407(Closure ,PythonFunction ,Object ,Object )\r\n   at IronPython.Runtime.FunctionCaller`2.Call2(CallSite site,CodeContext context,Object func,T0 arg0,T1 arg1)\r\n   at lambda_method(Closure ,Object[] ,StrongBox`1[] ,InterpretedFrame )\r\n   at Microsoft.Scripting.Interpreter.CompiledLoopInstruction.Run(InterpretedFrame frame)\r\n   at Microsoft.Scripting.Interpreter.Interpreter.Run(InterpretedFrame frame)\r\n   at Microsoft.Scripting.Interpreter.LightLambda.Run5[T0,T1,T2,T3,T4,TRet](T0 arg0,T1 arg1,T2 arg2,T3 arg3,T4 arg4)\r\n   at IronPython.Compiler.PythonCallTargets.OriginalCallTarget4(PythonFunction function,Object arg0,Object arg1,Object arg2,Object arg3)\r\n   at Microsoft.Scripting.Interpreter.FuncCallInstruction`7.Run(InterpretedFrame frame)\r\n   at Microsoft.Scripting.Interpreter.Interpreter.Run(InterpretedFrame frame)\r\n   at Microsoft.Scripting.Interpreter.LightLambda.Run7[T0,T1,T2,T3,T4,T5,T6,TRet](T0 arg0,T1 arg1,T2 arg2,T3 arg3,T4 arg4,T5 arg5,T6 arg6)\r\n   at System.Dynamic.UpdateDelegates.UpdateAndExecute6[T0,T1,T2,T3,T4,T5,TRet](CallSite site,T0 arg0,T1 arg1,T2 arg2,T3 arg3,T4 arg4,T5 arg5)\r\n   at Microsoft.Scripting.Interpreter.DynamicInstruction`7.Run(InterpretedFrame frame)\r\n   at Microsoft.Scripting.Interpreter.Interpreter.Run(InterpretedFrame frame)\r\n   at Microsoft.Scripting.Interpreter.LightLambda.Run2[T0,T1,TRet](T0 arg0,T1 arg1)\r\n   at IronPython.Runtime.FunctionCode.Call(CodeContext context)\r\n   at IronPython.Runtime.Operations.PythonOps.QualifiedExec(CodeContext context,Object code,PythonDictionary globals,Object locals)\r\n   at Microsoft.Scripting.Interpreter.ActionCallInstruction`4.Run(InterpretedFrame frame)\r\n   at Microsoft.Scripting.Interpreter.Interpreter.Run(InterpretedFrame frame)\r\n   at Microsoft.Scripting.Interpreter.LightLambda.Run8[T0,T1,T2,T3,T4,T5,T6,T7,TRet](T0 arg0,T1 arg1,T2 arg2,T3 arg3,T4 arg4,T5 arg5,T6 arg6,T7 arg7)\r\n   at IronPython.Compiler.PythonCallTargets.OriginalCallTarget7(PythonFunction function,Object arg0,Object arg1,Object arg2,Object arg3,Object arg4,Object arg5,Object arg6)\r\n   at IronPython.Runtime.FunctionCaller`7.Call7(CallSite site,CodeContext context,Object func,T0 arg0,T1 arg1,T2 arg2,T3 arg3,T4 arg4,T5 arg5,T6 arg6)\r\n   at System.Dynamic.UpdateDelegates.UpdateAndExecute9[T0,T1,T2,T3,T4,T5,T6,T7,T8,TRet](CallSite site,T0 arg0,T1 arg1,T2 arg2,T3 arg3,T4 arg4,T5 arg5,T6 arg6,T7 arg7,T8 arg8)\r\n   at Microsoft.Scripting.Interpreter.DynamicInstruction`10.Run(InterpretedFrame frame)\r\n   at Microsoft.Scripting.Interpreter.Interpreter.Run(InterpretedFrame frame)\r\n   at Microsoft.Scripting.Interpreter.LightLambda.Run7[T0,T1,T2,T3,T4,T5,T6,TRet](T0 arg0,T1 arg1,T2 arg2,T3 arg3,T4 arg4,T5 arg5,T6 arg6)\r\n   at IronPython.Compiler.PythonCallTargets.OriginalCallTarget6(PythonFunction function,Object arg0,Object arg1,Object arg2,Object arg3,Object arg4,Object arg5)\r\n   at IronPython.Runtime.FunctionCaller`6.Call6(CallSite site,CodeContext context,Object func,T0 arg0,T1 arg1,T2 arg2,T3 arg3,T4 arg4,T5 arg5)\r\n   at System.Dynamic.UpdateDelegates.UpdateAndExecute8[T0,T1,T2,T3,T4,T5,T6,T7,TRet](CallSite site,T0 arg0,T1 arg1,T2 arg2,T3 arg3,T4 arg4,T5 arg5,T6 arg6,T7 arg7)\r\n   at IronPython.Compiler.Ast.CallExpression.Invoke6Instruction.Run(InterpretedFrame frame)\r\n   at Microsoft.Scripting.Interpreter.Interpreter.Run(InterpretedFrame frame)\r\n   at Microsoft.Scripting.Interpreter.LightLambda.Run5[T0,T1,T2,T3,T4,TRet](T0 arg0,T1 arg1,T2 arg2,T3 arg3,T4 arg4)\r\n   at IronPython.Compiler.PythonCallTargets.OriginalCallTarget4(PythonFunction function,Object arg0,Object arg1,Object arg2,Object arg3)\r\n   at Microsoft.Scripting.Interpreter.FuncCallInstruction`7.Run(InterpretedFrame frame)\r\n   at Microsoft.Scripting.Interpreter.Interpreter.Run(InterpretedFrame frame)\r\n   at Microsoft.Scripting.Interpreter.LightLambda.Run5[T0,T1,T2,T3,T4,TRet](T0 arg0,T1 arg1,T2 arg2,T3 arg3,T4 arg4)\r\n   at System.Dynamic.UpdateDelegates.UpdateAndExecute4[T0,T1,T2,T3,TRet](CallSite site,T0 arg0,T1 arg1,T2 arg2,T3 arg3)\r\n   at IronPython.Runtime.PythonContext.CallWithKeywords(Object func,Object[] args,IDictionary`2 dict)\r\n   at IronPython.Runtime.Operations.PythonCalls.CallWithKeywordArgs(CodeContext context,Object func,Object[] args,String[] names)\r\n   at IronPython.Hosting.PythonCommandLine.Run()\r\n   at Microsoft.Scripting.Hosting.Shell.CommandLine.Run(ScriptEngine engine,IConsole console,ConsoleOptions options)\r\n   at Microsoft.Scripting.Hosting.Shell.ConsoleHost.RunCommandLine()\r\n   at Microsoft.Scripting.Hosting.Shell.ConsoleHost.ExecuteInternal()\r\n   at PythonConsoleHost.ExecuteInternal()\r\n   at Microsoft.Scripting.Hosting.Shell.ConsoleHost.Execute()\r\n   at Microsoft.Scripting.Hosting.Shell.ConsoleHost.Run(String[] args)\r\n   at PythonConsoleHost.Main(String[] args)'
 SystemDirectory='C:\\WINDOWS\\system32'
 SystemPageSize=4096
 TickCount=103779234
 UserDomainName='STUDIO-SSD'
 UserInteractive=True
 UserName='gtalarico'
 Version=None
 WorkingSet=None
 __all__=[
  'Exit',
  'ExpandEnvironmentVariables',
  'FailFast',
  'GetCommandLineArgs',
  'GetEnvironmentVariable',
  'GetEnvironmentVariables',
  'GetFolderPath',
  'GetLogicalDrives',
  'SetEnvironmentVariable',
  'SpecialFolder',
  'SpecialFolderOption',
 ]




class EventLogEntryCollection(object,ICollection,IEnumerable):
 """ Defines size and enumerators for a collection of System.Diagnostics.EventLogEntry instances. """
 def CopyTo(self,entries,index):
  """
  CopyTo(self: EventLogEntryCollection,entries: Array[EventLogEntry],index: int)

   Copies the elements of the System.Diagnostics.EventLogEntryCollection to an array of 

    System.Diagnostics.EventLogEntry instances,starting at a particular array index.

  

  

   entries: The one-dimensional array of System.Diagnostics.EventLogEntry instances that is the destination 

    of the elements copied from the collection. The array must have zero-based indexing.

  

   index: The zero-based index in the array at which copying begins.
  """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: EventLogEntryCollection) -> IEnumerator

  

   Supports a simple iteration over the System.Diagnostics.EventLogEntryCollection object.

   Returns: An object that can be used to iterate over the collection.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of entries in the event log (that is,the number of elements in the System.Diagnostics.EventLogEntry collection).



Get: Count(self: EventLogEntryCollection) -> int



"""





class PaddingConverter(TypeConverter):
 """
 Provides a type converter to convert System.Windows.Forms.Padding values to and from various other representations.

 

 PaddingConverter()
 """
 def CanConvertFrom(self,*__args):
  """
  CanConvertFrom(self: PaddingConverter,context: ITypeDescriptorContext,sourceType: Type) -> bool

  

   Returns whether this converter can convert an object of one type to the type of this converter.

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   sourceType: A System.Type that represents the type you wish to convert from.

   Returns: true if this object can perform the conversion; otherwise,false.
  """
  pass
 def CanConvertTo(self,*__args):
  """
  CanConvertTo(self: PaddingConverter,context: ITypeDescriptorContext,destinationType: Type) -> bool

  

   Returns whether this converter can convert the object to the specified type,using the specified 

    context.

  

  

   destinationType: A T:System.Type that represents the type you want to convert to.

   Returns: true if this converter can perform the conversion; otherwise,false.
  """
  pass
 def ConvertFrom(self,*__args):
  """
  ConvertFrom(self: PaddingConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object) -> object

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   culture: The System.Globalization.CultureInfo to use as the current culture.

   value: The System.Object to convert.
  """
  pass
 def ConvertTo(self,*__args):
  """
  ConvertTo(self: PaddingConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object,destinationType: Type) -> object

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   culture: A System.Globalization.CultureInfo. If null is passed,the current culture is assumed.

   value: The System.Object to convert.

   destinationType: The System.Type to convert the value parameter to.
  """
  pass
 def CreateInstance(self,*__args):
  """
  CreateInstance(self: PaddingConverter,context: ITypeDescriptorContext,propertyValues: IDictionary) -> object

  

   Creates an instance of the type that this System.ComponentModel.TypeConverter is associated 

    with,using the specified context,given a set of property values for the object.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   propertyValues: An System.Collections.IDictionary of new property values.

   Returns: An System.Object representing the given System.Collections.IDictionary,or null if the object 

    cannot be created. This method always returns null.
  """
  pass
 def GetCreateInstanceSupported(self,context=None):
  """
  GetCreateInstanceSupported(self: PaddingConverter,context: ITypeDescriptorContext) -> bool

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.
  """
  pass
 def GetProperties(self,*__args):
  """
  GetProperties(self: PaddingConverter,context: ITypeDescriptorContext,value: object,attributes: Array[Attribute]) -> PropertyDescriptorCollection

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   value: An System.Object that specifies the type of array for which to get properties.

   attributes: An array of type System.Attribute that is used as a filter.
  """
  pass
 def GetPropertiesSupported(self,context=None):
  """
  GetPropertiesSupported(self: PaddingConverter,context: ITypeDescriptorContext) -> bool

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.
  """
  pass



class ProcessModuleCollection(ReadOnlyCollectionBase,ICollection,IEnumerable):
 """
 Provides a strongly typed collection of System.Diagnostics.ProcessModule objects.

 

 ProcessModuleCollection(processModules: Array[ProcessModule])
 """
 def Contains(self,module):
  """
  Contains(self: ProcessModuleCollection,module: ProcessModule) -> bool

  

   Determines whether the specified process module exists in the collection.

  

   module: A System.Diagnostics.ProcessModule instance that indicates the module to find in this collection.

   Returns: true if the module exists in the collection; otherwise,false.
  """
  pass
 def CopyTo(self,array,index):
  """
  CopyTo(self: ProcessModuleCollection,array: Array[ProcessModule],index: int)

   Copies an array of System.Diagnostics.ProcessModule instances to the collection,at the 

    specified index.

  

  

   array: An array of System.Diagnostics.ProcessModule instances to add to the collection.

   index: The location at which to add the new instances.
  """
  pass
 def IndexOf(self,module):
  """
  IndexOf(self: ProcessModuleCollection,module: ProcessModule) -> int

  

   Provides the location of a specified module within the collection.

  

   module: The System.Diagnostics.ProcessModule whose index is retrieved.

   Returns: The zero-based index that defines the location of the module within the 

    System.Diagnostics.ProcessModuleCollection.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 @staticmethod
 def __new__(self,processModules):
  """
  __new__(cls: type)

  __new__(cls: type,processModules: Array[ProcessModule])
  """
  pass
 InnerList=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of elements contained in the System.Collections.ReadOnlyCollectionBase instance.



"""





class MemoryStream(Stream,IDisposable):
 """
 Creates a stream whose backing store is memory.

 

 MemoryStream()

 MemoryStream(capacity: int)

 MemoryStream(buffer: Array[Byte])

 MemoryStream(buffer: Array[Byte],writable: bool)

 MemoryStream(buffer: Array[Byte],index: int,count: int)

 MemoryStream(buffer: Array[Byte],index: int,count: int,writable: bool)

 MemoryStream(buffer: Array[Byte],index: int,count: int,writable: bool,publiclyVisible: bool)
 """
 def CopyToAsync(self,destination,bufferSize=None,cancellationToken=None):
  """ CopyToAsync(self: MemoryStream,destination: Stream,bufferSize: int,cancellationToken: CancellationToken) -> Task """
  pass
 def CreateWaitHandle(self,*args):
  """
  CreateWaitHandle(self: Stream) -> WaitHandle

  

   Allocates a System.Threading.WaitHandle object.

   Returns: A reference to the allocated WaitHandle.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: MemoryStream,disposing: bool)

   Releases the unmanaged resources used by the System.IO.MemoryStream class and optionally 

    releases the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def Flush(self):
  """
  Flush(self: MemoryStream)

   Overrides System.IO.Stream.Flush so that no action is performed.
  """
  pass
 def FlushAsync(self,cancellationToken=None):
  """ FlushAsync(self: MemoryStream,cancellationToken: CancellationToken) -> Task """
  pass
 def GetBuffer(self):
  """
  GetBuffer(self: MemoryStream) -> Array[Byte]

  

   Returns the array of unsigned bytes from which this stream was created.

   Returns: The byte array from which this stream was created,or the underlying array if a byte array was 

    not provided to the System.IO.MemoryStream constructor during construction of the current 

    instance.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def ObjectInvariant(self,*args):
  """
  ObjectInvariant(self: Stream)

   Provides support for a System.Diagnostics.Contracts.Contract.
  """
  pass
 def Read(self,buffer,offset,count):
  """
  Read(self: MemoryStream,offset: int,count: int) -> (int,Array[Byte])

  

   Reads a block of bytes from the current stream and writes the data to a buffer.

  

   offset: The zero-based byte offset in buffer at which to begin storing data from the current stream.

   count: The maximum number of bytes to read.

   Returns: The total number of bytes written into the buffer. This can be less than the number of bytes 

    requested if that number of bytes are not currently available,or zero if the end of the stream 

    is reached before any bytes are read.
  """
  pass
 def ReadAsync(self,buffer,offset,count,cancellationToken=None):
  """ ReadAsync(self: MemoryStream,buffer: Array[Byte],offset: int,count: int,cancellationToken: CancellationToken) -> Task[int] """
  pass
 def ReadByte(self):
  """
  ReadByte(self: MemoryStream) -> int

  

   Reads a byte from the current stream.

   Returns: The byte cast to a System.Int32,or -1 if the end of the stream has been reached.
  """
  pass
 def Seek(self,offset,loc):
  """
  Seek(self: MemoryStream,offset: Int64,loc: SeekOrigin) -> Int64

  

   Sets the position within the current stream to the specified value.

  

   offset: The new position within the stream. This is relative to the loc parameter,and can be positive 

    or negative.

  

   loc: A value of type System.IO.SeekOrigin,which acts as the seek reference point.

   Returns: The new position within the stream,calculated by combining the initial reference point and the 

    offset.
  """
  pass
 def SetLength(self,value):
  """
  SetLength(self: MemoryStream,value: Int64)

   Sets the length of the current stream to the specified value.

  

   value: The value at which to set the length.
  """
  pass
 def ToArray(self):
  """
  ToArray(self: MemoryStream) -> Array[Byte]

  

   Writes the stream contents to a byte array,regardless of the System.IO.MemoryStream.Position 

    property.

  

   Returns: A new byte array.
  """
  pass
 def TryGetBuffer(self,buffer):
  """ TryGetBuffer(self: MemoryStream) -> (bool,ArraySegment[Byte]) """
  pass
 def Write(self,buffer,offset,count):
  """
  Write(self: MemoryStream,buffer: Array[Byte],offset: int,count: int)

   Writes a block of bytes to the current stream using data read from a buffer.

  

   buffer: The buffer to write data from.

   offset: The zero-based byte offset in buffer at which to begin copying bytes to the current stream.

   count: The maximum number of bytes to write.
  """
  pass
 def WriteAsync(self,buffer,offset,count,cancellationToken=None):
  """ WriteAsync(self: MemoryStream,buffer: Array[Byte],offset: int,count: int,cancellationToken: CancellationToken) -> Task """
  pass
 def WriteByte(self,value):
  """
  WriteByte(self: MemoryStream,value: Byte)

   Writes a byte to the current stream at the current position.

  

   value: The byte to write.
  """
  pass
 def WriteTo(self,stream):
  """
  WriteTo(self: MemoryStream,stream: Stream)

   Writes the entire contents of this memory stream to another stream.

  

   stream: The stream to write this memory stream to.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,capacity: int)

  __new__(cls: type,buffer: Array[Byte])

  __new__(cls: type,buffer: Array[Byte],writable: bool)

  __new__(cls: type,buffer: Array[Byte],index: int,count: int)

  __new__(cls: type,buffer: Array[Byte],index: int,count: int,writable: bool)

  __new__(cls: type,buffer: Array[Byte],index: int,count: int,writable: bool,publiclyVisible: bool)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 CanRead=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the current stream supports reading.



Get: CanRead(self: MemoryStream) -> bool



"""

 CanSeek=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the current stream supports seeking.



Get: CanSeek(self: MemoryStream) -> bool



"""

 CanWrite=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the current stream supports writing.



Get: CanWrite(self: MemoryStream) -> bool



"""

 Capacity=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the number of bytes allocated for this stream.



Get: Capacity(self: MemoryStream) -> int



Set: Capacity(self: MemoryStream)=value

"""

 Length=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the length of the stream in bytes.



Get: Length(self: MemoryStream) -> Int64



"""

 Position=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the current position within the stream.



Get: Position(self: MemoryStream) -> Int64



Set: Position(self: MemoryStream)=value

"""





"""Definition List Extension for Python-Markdown.

Adds parsing of Definition Lists to Python-Markdown.

See <https://pythonhosted.org/Markdown/extensions/definition_lists.html>
for documentation.

Original code Copyright 2008 [Waylan Limberg](http://achinghead.com)

All changes Copyright 2008-2014 The Python Markdown Project

License: [BSD](http://www.opensource.org/licenses/bsd-license.php)
"""

from __future__ import absolute_import
from __future__ import unicode_literals
from . import Extension
from ..blockprocessors import BlockProcessor, ListIndentProcessor
from ..util import etree
import re


class DefListProcessor(BlockProcessor):
    """Process Definition Lists."""

    RE = re.compile(r'(^|\n)[ ]{0,3}:[ ]{1,3}(.*?)(\n|$)')
    NO_INDENT_RE = re.compile(r'^[ ]{0,3}[^ :]')

    def test(self, parent, block):
        return bool(self.RE.search(block))

    def run(self, parent, blocks):

        raw_block = blocks.pop(0)
        m = self.RE.search(raw_block)
        terms = [l.strip() for l in
                 raw_block[:m.start()].split('\n') if l.strip()]
        block = raw_block[m.end():]
        no_indent = self.NO_INDENT_RE.match(block)
        if no_indent:
            d, theRest = (block, None)
        else:
            d, theRest = self.detab(block)
        if d:
            d = '%s\n%s' % (m.group(2), d)
        else:
            d = m.group(2)
        sibling = self.lastChild(parent)
        if not terms and sibling is None:
            # This is not a definition item. Most likely a paragraph that
            # starts with a colon at the begining of a document or list.
            blocks.insert(0, raw_block)
            return False
        if not terms and sibling.tag == 'p':
            # The previous paragraph contains the terms
            state = 'looselist'
            terms = sibling.text.split('\n')
            parent.remove(sibling)
            # Aquire new sibling
            sibling = self.lastChild(parent)
        else:
            state = 'list'

        if sibling is not None and sibling.tag == 'dl':
            # This is another item on an existing list
            dl = sibling
            if not terms and len(dl) and dl[-1].tag == 'dd' and len(dl[-1]):
                state = 'looselist'
        else:
            # This is a new list
            dl = etree.SubElement(parent, 'dl')
        # Add terms
        for term in terms:
            dt = etree.SubElement(dl, 'dt')
            dt.text = term
        # Add definition
        self.parser.state.set(state)
        dd = etree.SubElement(dl, 'dd')
        self.parser.parseBlocks(dd, [d])
        self.parser.state.reset()

        if theRest:
            blocks.insert(0, theRest)


class DefListIndentProcessor(ListIndentProcessor):
    """Process indented children of definition list items."""

    ITEM_TYPES = ['dd']
    LIST_TYPES = ['dl']

    def create_item(self, parent, block):
        """Create a new dd and parse the block with it as the parent."""
        dd = etree.SubElement(parent, 'dd')
        self.parser.parseBlocks(dd, [block])


class DefListExtension(Extension):
    """Add definition lists to Markdown."""

    def extendMarkdown(self, md, md_globals):
        """Add an instance of DefListProcessor to BlockParser."""
        md.parser.blockprocessors.add('defindent',
                                      DefListIndentProcessor(md.parser),
                                      '>indent')
        md.parser.blockprocessors.add('deflist',
                                      DefListProcessor(md.parser),
                                      '>ulist')


def makeExtension(*args, **kwargs):
    return DefListExtension(*args, **kwargs)



class DataObjectMethodAttribute(Attribute,_Attribute):
 """
 Identifies a data operation method exposed by a type,what type of operation the method performs,and whether the method is the default data method. This class cannot be inherited.

 

 DataObjectMethodAttribute(methodType: DataObjectMethodType)

 DataObjectMethodAttribute(methodType: DataObjectMethodType,isDefault: bool)
 """
 def Equals(self,obj):
  """
  Equals(self: DataObjectMethodAttribute,obj: object) -> bool

  

   Returns a value indicating whether this instance is equal to a specified object.

  

   obj: An object to compare with this instance of System.ComponentModel.DataObjectMethodAttribute.

   Returns: true if this instance is the same as the instance specified by the obj parameter; otherwise,

    false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: DataObjectMethodAttribute) -> int

  

   Returns the hash code for this instance.

   Returns: A 32-bit signed integer hash code.
  """
  pass
 def Match(self,obj):
  """
  Match(self: DataObjectMethodAttribute,obj: object) -> bool

  

   Gets a value indicating whether this instance shares a common pattern with a specified attribute.

  

   obj: An object to compare with this instance of System.ComponentModel.DataObjectMethodAttribute.

   Returns: true if this instance is the same as the instance specified by the obj parameter; otherwise,

    false.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,methodType,isDefault=None):
  """
  __new__(cls: type,methodType: DataObjectMethodType)

  __new__(cls: type,methodType: DataObjectMethodType,isDefault: bool)
  """
  pass
 def __ne__(self,*args):
  pass
 IsDefault=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the method that the System.ComponentModel.DataObjectMethodAttribute is applied to is the default data method exposed by the data object for a specific method type.



Get: IsDefault(self: DataObjectMethodAttribute) -> bool



"""

 MethodType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.ComponentModel.DataObjectMethodType value indicating the type of data operation the method performs.



Get: MethodType(self: DataObjectMethodAttribute) -> DataObjectMethodType



"""





class ITypeLibExporterNotifySink:
 """ Provides a callback mechanism for the assembly converter to inform the caller of the status of the conversion,and involve the caller in the conversion process itself. """
 def ReportEvent(self,eventKind,eventCode,eventMsg):
  """
  ReportEvent(self: ITypeLibExporterNotifySink,eventKind: ExporterEventKind,eventCode: int,eventMsg: str)

   Notifies the caller that an event occured during the conversion of an assembly.

  

   eventKind: An System.Runtime.InteropServices.ExporterEventKind value indicating the type of event.

   eventCode: Indicates extra information about the event.

   eventMsg: A message generated by the event.
  """
  pass
 def ResolveRef(self,assembly):
  """
  ResolveRef(self: ITypeLibExporterNotifySink,assembly: Assembly) -> object

  

   Asks the user to resolve a reference to another assembly.

  

   assembly: The assembly to resolve.

   Returns: The type library for assembly.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class AsyncOperation(object):
 """ Tracks the lifetime of an asynchronous operation. """
 def OperationCompleted(self):
  """
  OperationCompleted(self: AsyncOperation)

   Ends the lifetime of an asynchronous operation.
  """
  pass
 def Post(self,d,arg):
  """
  Post(self: AsyncOperation,d: SendOrPostCallback,arg: object)

   Invokes a delegate on the thread or context appropriate for the application model.

  

   d: A System.Threading.SendOrPostCallback object that wraps the delegate to be called when the 

    operation ends.

  

   arg: An argument for the delegate contained in the d parameter.
  """
  pass
 def PostOperationCompleted(self,d,arg):
  """
  PostOperationCompleted(self: AsyncOperation,d: SendOrPostCallback,arg: object)

   Ends the lifetime of an asynchronous operation.

  

   d: A System.Threading.SendOrPostCallback object that wraps the delegate to be called when the 

    operation ends.

  

   arg: An argument for the delegate contained in the d parameter.
  """
  pass
 SynchronizationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Threading.SynchronizationContext object that was passed to the constructor.



Get: SynchronizationContext(self: AsyncOperation) -> SynchronizationContext



"""

 UserSuppliedState=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets an object used to uniquely identify an asynchronous operation.



Get: UserSuppliedState(self: AsyncOperation) -> object



"""





class AttributeProviderAttribute(Attribute,_Attribute):
 """
 Enables attribute redirection. This class cannot be inherited.

 

 AttributeProviderAttribute(typeName: str)

 AttributeProviderAttribute(typeName: str,propertyName: str)

 AttributeProviderAttribute(type: Type)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,typeName: str)

  __new__(cls: type,typeName: str,propertyName: str)

  __new__(cls: type,type: Type)
  """
  pass
 PropertyName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the property for which attributes will be retrieved.



Get: PropertyName(self: AttributeProviderAttribute) -> str



"""

 TypeName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the assembly qualified type name passed into the constructor.



Get: TypeName(self: AttributeProviderAttribute) -> str



"""





class CLSCompliantAttribute(Attribute,_Attribute):
 """
 Indicates whether a program element is compliant with the Common Language Specification (CLS). This class cannot be inherited.

 

 CLSCompliantAttribute(isCompliant: bool)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,isCompliant):
  """ __new__(cls: type,isCompliant: bool) """
  pass
 def __reduce_ex__(self,*args):
  pass
 IsCompliant=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the Boolean value indicating whether the indicated program element is CLS-compliant.



Get: IsCompliant(self: CLSCompliantAttribute) -> bool



"""





class EndPoint(object):
 """ Identifies a network address. This is an abstract class. """
 def Create(self,socketAddress):
  """
  Create(self: EndPoint,socketAddress: SocketAddress) -> EndPoint

  

   Creates an System.Net.EndPoint instance from a System.Net.SocketAddress instance.

  

   socketAddress: The socket address that serves as the endpoint for a connection.

   Returns: A new System.Net.EndPoint instance that is initialized from the specified 

    System.Net.SocketAddress instance.
  """
  pass
 def Serialize(self):
  """
  Serialize(self: EndPoint) -> SocketAddress

  

   Serializes endpoint information into a System.Net.SocketAddress instance.

   Returns: A System.Net.SocketAddress instance that contains the endpoint information.
  """
  pass
 AddressFamily=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the address family to which the endpoint belongs.



Get: AddressFamily(self: EndPoint) -> AddressFamily



"""





class ItemContainerTemplate(DataTemplate,INameScope,ISealable,IHaveResources,IQueryAmbient):
 """ ItemContainerTemplate() """
 def ValidateTemplatedParent(self,*args):
  """
  ValidateTemplatedParent(self: DataTemplate,templatedParent: FrameworkElement)

   Checks the templated parent against a set of rules.

  

   templatedParent: The element this template is applied to.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 ItemContainerTemplateKey=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: ItemContainerTemplateKey(self: ItemContainerTemplate) -> object



"""





class ToolBarButton(Component,IComponent,IDisposable):
 """
 Represents a Windows toolbar button. Although System.Windows.Forms.ToolStripButton replaces and extends the System.Windows.Forms.ToolBarButton control of previous versions,System.Windows.Forms.ToolBarButton is retained for both backward compatibility and future use if you choose.

 

 ToolBarButton()

 ToolBarButton(text: str)
 """
 def Dispose(self):
  """
  Dispose(self: ToolBarButton,disposing: bool)

   Releases the unmanaged resources used by the System.Windows.Forms.ToolBarButton and optionally 

    releases the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def GetService(self,*args):
  """
  GetService(self: Component,service: Type) -> object

  

   Returns an object that represents a service provided by the System.ComponentModel.Component or 

    by its System.ComponentModel.Container.

  

  

   service: A service provided by the System.ComponentModel.Component.

   Returns: An System.Object that represents a service provided by the System.ComponentModel.Component,or 

    null if the System.ComponentModel.Component does not provide the specified service.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def ToString(self):
  """
  ToString(self: ToolBarButton) -> str

  

   Returns a string that represents the System.Windows.Forms.ToolBarButton control.

   Returns: A string that represents the current System.Windows.Forms.ToolBarButton.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,text=None):
  """
  __new__(cls: type)

  __new__(cls: type,text: str)
  """
  pass
 def __str__(self,*args):
  pass
 CanRaiseEvents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the component can raise an event.



"""

 DesignMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.ComponentModel.Component is currently in design mode.



"""

 DropDownMenu=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the menu to be displayed in the drop-down toolbar button.



Get: DropDownMenu(self: ToolBarButton) -> Menu



Set: DropDownMenu(self: ToolBarButton)=value

"""

 Enabled=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the button is enabled.



Get: Enabled(self: ToolBarButton) -> bool



Set: Enabled(self: ToolBarButton)=value

"""

 Events=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of event handlers that are attached to this System.ComponentModel.Component.



"""

 ImageIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the index value of the image assigned to the button.



Get: ImageIndex(self: ToolBarButton) -> int



Set: ImageIndex(self: ToolBarButton)=value

"""

 ImageKey=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the image assigned to the button.



Get: ImageKey(self: ToolBarButton) -> str



Set: ImageKey(self: ToolBarButton)=value

"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """The name of the button.



Get: Name(self: ToolBarButton) -> str



Set: Name(self: ToolBarButton)=value

"""

 Parent=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the toolbar control that the toolbar button is assigned to.



Get: Parent(self: ToolBarButton) -> ToolBar



"""

 PartialPush=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether a toggle-style toolbar button is partially pushed.



Get: PartialPush(self: ToolBarButton) -> bool



Set: PartialPush(self: ToolBarButton)=value

"""

 Pushed=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether a toggle-style toolbar button is currently in the pushed state.



Get: Pushed(self: ToolBarButton) -> bool



Set: Pushed(self: ToolBarButton)=value

"""

 Rectangle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the bounding rectangle for a toolbar button.



Get: Rectangle(self: ToolBarButton) -> Rectangle



"""

 Style=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the style of the toolbar button.



Get: Style(self: ToolBarButton) -> ToolBarButtonStyle



Set: Style(self: ToolBarButton)=value

"""

 Tag=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the object that contains data about the toolbar button.



Get: Tag(self: ToolBarButton) -> object



Set: Tag(self: ToolBarButton)=value

"""

 Text=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the text displayed on the toolbar button.



Get: Text(self: ToolBarButton) -> str



Set: Text(self: ToolBarButton)=value

"""

 ToolTipText=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the text that appears as a ToolTip for the button.



Get: ToolTipText(self: ToolBarButton) -> str



Set: ToolTipText(self: ToolBarButton)=value

"""

 Visible=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the toolbar button is visible.



Get: Visible(self: ToolBarButton) -> bool



Set: Visible(self: ToolBarButton)=value

"""





class BStrWrapper(object):
 """
 Marshals data of type VT_BSTR from managed to unmanaged code. This class cannot be inherited.

 

 BStrWrapper(value: str)

 BStrWrapper(value: object)
 """
 @staticmethod
 def __new__(self,value):
  """
  __new__(cls: type,value: str)

  __new__(cls: type,value: object)
  """
  pass
 WrappedObject=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the wrapped System.String object to marshal as type VT_BSTR.



Get: WrappedObject(self: BStrWrapper) -> str



"""





class OutAttribute(Attribute,_Attribute):
 """
 Indicates that data should be marshaled from callee back to caller.

 

 OutAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
